import * as i0 from '@angular/core';
import { ChangeDetectionStrategy, Component } from '@angular/core';
import { e as CoreWorkflowListComponent, d as CorePageHeaderComponent, f as TooltipDirective, D as DragReorderDirective, F as FullscreenModalLoaderComponent } from './ngx-histaff-alpha-ngx-histaff-alpha-0x5r9IS0.mjs';
import { RouterOutlet } from '@angular/router';
import { buffer, debounceTime, filter, distinctUntilChanged, switchMap, catchError, of } from 'rxjs';

class CoreWorkflowConsumeComponent extends CoreWorkflowListComponent {
    sendRequest(flow) {
        if (!!flow.afNormalMode) {
            // Fullscreen route
            this.router.navigate(['/root/workflow/workflow-consume', flow.id]);
        }
        else {
            // Modal outlet route
            this.router.navigate([
                '/root/workflow/workflow-consume',
                { outlets: { workflowConsume: [flow.id] } }
            ]);
        }
    }
    ngAfterViewInit() {
        this.doublePointDown?.unsubscribe();
        requestAnimationFrame(() => {
            this.coreWorkflowService.refresh('/api/WfWorkflowGroup/GetAllAvailableWithWorkflows', '');
            this.subscriptions.push(this.pointerdown$.pipe(buffer(this.pointerdown$.pipe(debounceTime(500))), filter(clicks => clicks.length >= 2)).subscribe(() => {
                if (!!this.$activeWorkflow()) {
                    this.sendRequest(this.$activeWorkflow());
                }
            }));
            this.subscriptions.push(this.orderChanges$
                .pipe(debounceTime(800), // wait 800ms after last change
            distinctUntilChanged((a, b) => JSON.stringify(a.map(x => ({ id: x.id, orderNum: x.orderNum }))) ===
                JSON.stringify(b.map(x => ({ id: x.id, orderNum: x.orderNum })))), switchMap(newOrder => this.coreWorkflowService.updateGroupOrder(newOrder)), catchError(err => {
                console.error('🚨 Backend update failed:', err);
                return of({ ok: false, status: 500, body: { statusCode: 500 } });
            }))
                .subscribe(x => {
                if (x.ok && x.status === 200 && x.body?.statusCode === 200) {
                    // no need to send any UI alert            
                }
            }));
            this.subscriptions.push(this.searchTearm$.pipe(debounceTime(500), distinctUntilChanged()).subscribe(searchTerm => {
                this.coreWorkflowService.refresh('/api/WfWorkflowGroup/GetAllAvailableWithWorkflows', searchTerm);
            }));
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.5", ngImport: i0, type: CoreWorkflowConsumeComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.2.5", type: CoreWorkflowConsumeComponent, isStandalone: true, selector: "core-workflow-consume", usesInheritance: true, ngImport: i0, template: "<div class=\"core-workflow-list-container\">\r\n\r\n    <core-page-header title=\"Workflow Use\" [hideButtonGroup]=\"true\"></core-page-header>\r\n    <div class=\"container-fluid\">\r\n        <div class=\"row gx-5 gy-5\" [class.sort-mode]=\"$sortMode()\">\r\n            <div class=\"col-md-12 no-padding\">\r\n                <div class=\"WorkflowList_operations d-flex d-flex-between\">\r\n                    <div class=\"WorkflowList_operationsLeft\">\r\n                        <input type=\"text\" placeholder=\"Search\" class=\"form-control\" [class.d-none]=\"$sortMode()\"\r\n                            (input)=\"onSearchChange($event)\"\r\n                        >\r\n                    </div>\r\n                    <div class=\"WorkflowList_operationsRight\">\r\n                        <button class=\"btn btn-secondary\" (click)=\"togglerSortMode()\">{{ $sortMode() ? 'Expand' : 'Sort'\r\n                            }}</button>\r\n                    </div>\r\n                </div>\r\n            </div>\r\n\r\n\r\n            <div class=\"group-list p-relative\">\r\n\r\n                @for (group of coreWorkflowService.$allGroups(); track group.id) {\r\n\r\n                    @if ($sortMode()) {\r\n\r\n                        <div class=\"WorkflowGroup card sort-mode\"\r\n                            [attr.data-id]=\"group.id\"\r\n                            dragReorder\r\n                            (updateList)=\"onListReorderUpdate($event)\"\r\n                            >\r\n            \r\n                            <div class=\"WorkflowGroup_header d-flex d-flex-between pointer\">\r\n                                <div class=\"WorkflowGroup_headerTitle\">\r\n                                    {{ group?.name }}\r\n                                </div>\r\n            \r\n                                <div class=\"WorkflowGroup_nameOperations d-flex d-flex-end\">\r\n            \r\n                                    <div class=\"WorkflowGroup_itemEdit pointer\">\r\n                                        <i class=\"feather-move\"></i>\r\n                                    </div>\r\n            \r\n                                </div>\r\n            \r\n                            </div>\r\n            \r\n                        </div>\r\n\r\n                    } @else {\r\n\r\n                        <div class=\"WorkflowGroup card\">\r\n        \r\n                            <div class=\"WorkflowGroup_header d-flex d-flex-between\">\r\n\r\n                                <div class=\"WorkflowGroup_headerTitle\">\r\n                                    {{ group?.name }}\r\n                                </div>\r\n                        \r\n                            </div>\r\n        \r\n        \r\n                        <div class=\"Workflows\">\r\n                            @for (flow of group.wfWorkflows; track $index) {\r\n                            <div class=\"Workflow pointer\" (pointerdown)=\"onPointerdown(flow, group)\">\r\n                                <div class=\"Workflow_code\">\r\n\r\n                                    <span [appTooltip]=\"flow.description\" [position]=\"'above'\" [showAnyway]=\"true\">{{ flow.name\r\n                                        }}</span>\r\n                                </div>\r\n                                <div class=\"Workflow_operationsRight\">\r\n                                    <div class=\"pointer\" (click)=\"sendRequest(flow)\"\r\n                                        [appTooltip]=\"'Send request'\">\r\n                                        <i class=\"feather-mail\"></i>\r\n                                    </div>\r\n                                </div>\r\n                            </div>\r\n                            }\r\n                        </div>\r\n        \r\n                    </div>\r\n\r\n                    }\r\n                }\r\n            </div>\r\n        </div>\r\n    </div>\r\n\r\n    <router-outlet name=\"workflowConsume\"></router-outlet>\r\n\r\n    @if ($loading()) {\r\n        <app-fullscreen-modal-loader/>\r\n    }\r\n\r\n</div>", styles: [".core-workflow-list-container{padding:1rem}.core-workflow-list-container .container-fluid{max-width:800px}.core-workflow-list-container .WorkflowList_operations{margin-bottom:1rem;border-bottom:1px solid #ddd;padding-bottom:.5rem}.core-workflow-list-container .WorkflowList_operations input.form-control{max-width:250px;border-radius:8px;transition:all .3s ease}.core-workflow-list-container .WorkflowList_operations button.btn{border-radius:8px;padding:.4rem 1rem}.core-workflow-list-container .WorkflowGroup{border-radius:12px;box-shadow:0 3px 8px #0000000f;padding:1rem;margin-bottom:1.5rem;transition:box-shadow .3s ease,transform .3s ease}.core-workflow-list-container .WorkflowGroup.sort-mode{border:2px dashed #0d6efd;background:#f9f9f9;cursor:move}.core-workflow-list-container .WorkflowGroup.sort-mode .WorkflowGroup_header{margin-bottom:0}.core-workflow-list-container .WorkflowGroup:hover:not(.sort-mode){transform:translateY(-3px);box-shadow:0 6px 12px #00000014}.core-workflow-list-container .WorkflowGroup .WorkflowGroup_header{margin-bottom:1rem;font-size:1.25rem;font-weight:600;color:#333}.core-workflow-list-container .WorkflowGroup .WorkflowGroup_itemEdit{padding:.25rem;color:#6c757d;transition:color .3s}.core-workflow-list-container .WorkflowGroup .WorkflowGroup_itemEdit:hover{color:#0d6efd}.core-workflow-list-container .WorkflowGroup .WorkflowGroup_itemEdit i{font-size:1.1rem}.core-workflow-list-container .WorkflowGroup .Workflows{display:grid;grid-template-columns:repeat(auto-fit,minmax(220px,1fr));gap:.75rem}.core-workflow-list-container .WorkflowGroup .Workflow{background:#f8f9fa;border:1px solid #dee2e6;border-radius:8px;padding:.75rem 1rem;display:flex;justify-content:space-between;align-items:center;transition:background .3s,transform .2s ease;position:relative}.core-workflow-list-container .WorkflowGroup .Workflow:hover{background:#e9ecef;transform:translateY(-1px)}.core-workflow-list-container .WorkflowGroup .Workflow .Workflow_code{font-weight:500;color:#212529;overflow:hidden;text-overflow:ellipsis;text-wrap:nowrap}.core-workflow-list-container .WorkflowGroup .Workflow .Workflow_operationsRight{display:flex;align-items:center}.core-workflow-list-container .WorkflowGroup .Workflow .Workflow_operationsRight .feather-mail{font-size:1.5rem;width:1.5rem;height:1.5rem;display:flex;color:var(--bg-orange);transition:transform .2s;margin-left:8px}.core-workflow-list-container .WorkflowGroup .Workflow .Workflow_operationsRight .feather-mail:hover{transform:scale(1.2)}.core-workflow-list-container .group-list{position:relative}.core-workflow-list-container.sort-mode .WorkflowGroup{cursor:move}\n"], dependencies: [{ kind: "directive", type: RouterOutlet, selector: "router-outlet", inputs: ["name", "routerOutletData"], outputs: ["activate", "deactivate", "attach", "detach"], exportAs: ["outlet"] }, { kind: "component", type: CorePageHeaderComponent, selector: "core-page-header", inputs: ["instanceNumber", "shownItems", "title", "hideButtonGroup", "htmlTooltipRef"], outputs: ["buttonClick"] }, { kind: "directive", type: TooltipDirective, selector: "[appTooltip]", inputs: ["color", "backgroundColor", "appTooltip", "showAnyway", "position"] }, { kind: "directive", type: DragReorderDirective, selector: "[dragReorder]", inputs: ["item"], outputs: ["updateList"] }, { kind: "component", type: FullscreenModalLoaderComponent, selector: "app-fullscreen-modal-loader", inputs: ["content"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.5", ngImport: i0, type: CoreWorkflowConsumeComponent, decorators: [{
            type: Component,
            args: [{ selector: 'core-workflow-consume', changeDetection: ChangeDetectionStrategy.OnPush, imports: [
                        RouterOutlet,
                        CorePageHeaderComponent,
                        TooltipDirective,
                        DragReorderDirective,
                        FullscreenModalLoaderComponent
                    ], template: "<div class=\"core-workflow-list-container\">\r\n\r\n    <core-page-header title=\"Workflow Use\" [hideButtonGroup]=\"true\"></core-page-header>\r\n    <div class=\"container-fluid\">\r\n        <div class=\"row gx-5 gy-5\" [class.sort-mode]=\"$sortMode()\">\r\n            <div class=\"col-md-12 no-padding\">\r\n                <div class=\"WorkflowList_operations d-flex d-flex-between\">\r\n                    <div class=\"WorkflowList_operationsLeft\">\r\n                        <input type=\"text\" placeholder=\"Search\" class=\"form-control\" [class.d-none]=\"$sortMode()\"\r\n                            (input)=\"onSearchChange($event)\"\r\n                        >\r\n                    </div>\r\n                    <div class=\"WorkflowList_operationsRight\">\r\n                        <button class=\"btn btn-secondary\" (click)=\"togglerSortMode()\">{{ $sortMode() ? 'Expand' : 'Sort'\r\n                            }}</button>\r\n                    </div>\r\n                </div>\r\n            </div>\r\n\r\n\r\n            <div class=\"group-list p-relative\">\r\n\r\n                @for (group of coreWorkflowService.$allGroups(); track group.id) {\r\n\r\n                    @if ($sortMode()) {\r\n\r\n                        <div class=\"WorkflowGroup card sort-mode\"\r\n                            [attr.data-id]=\"group.id\"\r\n                            dragReorder\r\n                            (updateList)=\"onListReorderUpdate($event)\"\r\n                            >\r\n            \r\n                            <div class=\"WorkflowGroup_header d-flex d-flex-between pointer\">\r\n                                <div class=\"WorkflowGroup_headerTitle\">\r\n                                    {{ group?.name }}\r\n                                </div>\r\n            \r\n                                <div class=\"WorkflowGroup_nameOperations d-flex d-flex-end\">\r\n            \r\n                                    <div class=\"WorkflowGroup_itemEdit pointer\">\r\n                                        <i class=\"feather-move\"></i>\r\n                                    </div>\r\n            \r\n                                </div>\r\n            \r\n                            </div>\r\n            \r\n                        </div>\r\n\r\n                    } @else {\r\n\r\n                        <div class=\"WorkflowGroup card\">\r\n        \r\n                            <div class=\"WorkflowGroup_header d-flex d-flex-between\">\r\n\r\n                                <div class=\"WorkflowGroup_headerTitle\">\r\n                                    {{ group?.name }}\r\n                                </div>\r\n                        \r\n                            </div>\r\n        \r\n        \r\n                        <div class=\"Workflows\">\r\n                            @for (flow of group.wfWorkflows; track $index) {\r\n                            <div class=\"Workflow pointer\" (pointerdown)=\"onPointerdown(flow, group)\">\r\n                                <div class=\"Workflow_code\">\r\n\r\n                                    <span [appTooltip]=\"flow.description\" [position]=\"'above'\" [showAnyway]=\"true\">{{ flow.name\r\n                                        }}</span>\r\n                                </div>\r\n                                <div class=\"Workflow_operationsRight\">\r\n                                    <div class=\"pointer\" (click)=\"sendRequest(flow)\"\r\n                                        [appTooltip]=\"'Send request'\">\r\n                                        <i class=\"feather-mail\"></i>\r\n                                    </div>\r\n                                </div>\r\n                            </div>\r\n                            }\r\n                        </div>\r\n        \r\n                    </div>\r\n\r\n                    }\r\n                }\r\n            </div>\r\n        </div>\r\n    </div>\r\n\r\n    <router-outlet name=\"workflowConsume\"></router-outlet>\r\n\r\n    @if ($loading()) {\r\n        <app-fullscreen-modal-loader/>\r\n    }\r\n\r\n</div>", styles: [".core-workflow-list-container{padding:1rem}.core-workflow-list-container .container-fluid{max-width:800px}.core-workflow-list-container .WorkflowList_operations{margin-bottom:1rem;border-bottom:1px solid #ddd;padding-bottom:.5rem}.core-workflow-list-container .WorkflowList_operations input.form-control{max-width:250px;border-radius:8px;transition:all .3s ease}.core-workflow-list-container .WorkflowList_operations button.btn{border-radius:8px;padding:.4rem 1rem}.core-workflow-list-container .WorkflowGroup{border-radius:12px;box-shadow:0 3px 8px #0000000f;padding:1rem;margin-bottom:1.5rem;transition:box-shadow .3s ease,transform .3s ease}.core-workflow-list-container .WorkflowGroup.sort-mode{border:2px dashed #0d6efd;background:#f9f9f9;cursor:move}.core-workflow-list-container .WorkflowGroup.sort-mode .WorkflowGroup_header{margin-bottom:0}.core-workflow-list-container .WorkflowGroup:hover:not(.sort-mode){transform:translateY(-3px);box-shadow:0 6px 12px #00000014}.core-workflow-list-container .WorkflowGroup .WorkflowGroup_header{margin-bottom:1rem;font-size:1.25rem;font-weight:600;color:#333}.core-workflow-list-container .WorkflowGroup .WorkflowGroup_itemEdit{padding:.25rem;color:#6c757d;transition:color .3s}.core-workflow-list-container .WorkflowGroup .WorkflowGroup_itemEdit:hover{color:#0d6efd}.core-workflow-list-container .WorkflowGroup .WorkflowGroup_itemEdit i{font-size:1.1rem}.core-workflow-list-container .WorkflowGroup .Workflows{display:grid;grid-template-columns:repeat(auto-fit,minmax(220px,1fr));gap:.75rem}.core-workflow-list-container .WorkflowGroup .Workflow{background:#f8f9fa;border:1px solid #dee2e6;border-radius:8px;padding:.75rem 1rem;display:flex;justify-content:space-between;align-items:center;transition:background .3s,transform .2s ease;position:relative}.core-workflow-list-container .WorkflowGroup .Workflow:hover{background:#e9ecef;transform:translateY(-1px)}.core-workflow-list-container .WorkflowGroup .Workflow .Workflow_code{font-weight:500;color:#212529;overflow:hidden;text-overflow:ellipsis;text-wrap:nowrap}.core-workflow-list-container .WorkflowGroup .Workflow .Workflow_operationsRight{display:flex;align-items:center}.core-workflow-list-container .WorkflowGroup .Workflow .Workflow_operationsRight .feather-mail{font-size:1.5rem;width:1.5rem;height:1.5rem;display:flex;color:var(--bg-orange);transition:transform .2s;margin-left:8px}.core-workflow-list-container .WorkflowGroup .Workflow .Workflow_operationsRight .feather-mail:hover{transform:scale(1.2)}.core-workflow-list-container .group-list{position:relative}.core-workflow-list-container.sort-mode .WorkflowGroup{cursor:move}\n"] }]
        }] });

export { CoreWorkflowConsumeComponent };
//# sourceMappingURL=ngx-histaff-alpha-core-workflow-consume.component-Oo_P1fdC.mjs.map
