import * as i0 from '@angular/core';
import { inject, Injector, signal, ChangeDetectionStrategy, Component } from '@angular/core';
import * as i1 from '@angular/forms';
import { FormsModule } from '@angular/forms';
import { c as BaseComponent, C as CoreWorkflowService, d as CorePageHeaderComponent, T as TranslatePipe } from './ngx-histaff-alpha-ngx-histaff-alpha-0x5r9IS0.mjs';
import { Subject, BehaviorSubject, tap, debounceTime, distinctUntilChanged, switchMap, catchError, of, filter, finalize } from 'rxjs';
import { D as DbService, C as CoreToastLoadingComponent, A as AiHintForColumnComponent } from './ngx-histaff-alpha-core-toast-loading.component-BGH6zSfv.mjs';

class DbSettingsComponent extends BaseComponent {
    constructor() {
        super(...arguments);
        this.wfs = inject(CoreWorkflowService);
        this.dbs = inject(DbService);
        this.injector = inject(Injector);
        // $schema = this.wfs.$workflowDbSchema;
        this.$loading = signal(false);
        this.$sortMode = signal(false);
        this.$activeHintEditor = signal(null);
        this.orderChanges$ = new Subject();
        this.activeColumnsChanges$ = new Subject();
        this.$totalItems = signal(0);
        this.searchTerm = '';
        this.search$ = new BehaviorSubject('');
        this.getListStream$ = new BehaviorSubject(null);
    }
    onFieldToggle(table, e) {
        this.updateTableStatus(table, !!e.length);
        this.activeColumnsChanges$.next({ table: table.table, activeColumns: e });
    }
    openHintEditor(table, e) {
        const { column } = e.item;
        this.$activeHintEditor.set({
            table,
            column,
            top: e.e.clientY,
            left: e.e.clientX,
        });
    }
    closeHintEditor() {
        this.$activeHintEditor.set(null);
    }
    onSearchChange(e) {
        this.search$.next(e);
    }
    getActiveColumnNameArray(table) {
        return this.wfs.$workflowDbSchema().filter(x => x.table === table)[0].columns.filter(x => !!x.isActive).map(x => x.column);
    }
    updateTableStatus(table, isActive) {
        if (table.isActive === isActive)
            return;
        const updated = this.wfs.$workflowDbSchema().map(t => t.table === table.table
            ? {
                ...t,
                isActive,
                columns: t.columns.map(c => ({ ...c, isActive }))
            }
            : t);
        this.wfs.$workflowDbSchema.set([...updated]);
    }
    togglerSortMode() {
        this.$sortMode.set(!this.$sortMode());
    }
    updateColumnStatus(table, selectedColumns) {
        const updated = this.wfs.$workflowDbSchema().map(t => t.table === table.table
            ? {
                ...t,
                columns: t.columns.map(c => ({
                    ...c,
                    isActive: selectedColumns.includes(c.column)
                })),
                isActive: selectedColumns.length > 0
            }
            : t);
        this.wfs.$workflowDbSchema.set(updated);
    }
    save() {
        const payload = this.wfs.$workflowDbSchema().map(table => ({
            table: table.table,
            isActive: table.isActive,
            columns: table.columns.map(c => ({
                column: c.column,
                isActive: c.isActive,
                hintForAi: c.hintForAi
            }))
        }));
        console.log('Saving schema payload:', payload);
        // Optional: Call API to save
        // this.http.post('/api/.../UpdateWorkflowSchema', payload).subscribe(...)
    }
    ngAfterViewInit() {
        this.subscriptions.push(this.orderChanges$
            .pipe(tap(_ => {
            console.log("this.orderChanges$ changed");
        }), debounceTime(800), // wait 800ms after last change
        distinctUntilChanged((a, b) => JSON.stringify(a.map(x => ({ id: x.id, orderNum: x.orderNum }))) ===
            JSON.stringify(b.map(x => ({ id: x.id, orderNum: x.orderNum })))), switchMap(newOrder => this.wfs.updateTableOrder(newOrder)), catchError(err => {
            console.error('🚨 Backend update failed:', err);
            return of({ ok: false, status: 500, body: { statusCode: 500 } });
        }))
            .subscribe(x => {
            if (x.ok && x.status === 200 && x.body?.statusCode === 200) {
                // no need to send any UI alert            
            }
        }));
        this.subscriptions.push(this.activeColumnsChanges$
            .pipe(tap(_ => {
            console.log("this.activeColumnsChanges$ changed");
        }), debounceTime(800), // wait 800ms after last change
        distinctUntilChanged((a, b) => JSON.stringify(a) === JSON.stringify(b)), switchMap(newState => this.dbs.updateColumnStatus(newState.table, newState.activeColumns)), catchError(err => {
            console.error('🚨 Backend update failed:', err);
            return of({ ok: false, status: 500, body: { statusCode: 500 } });
        }))
            .subscribe(x => {
            if (x.ok && x.status === 200 && x.body?.statusCode === 200) {
                // no need to send any UI alert            
            }
        }));
        this.subscriptions.push(this.search$.pipe(debounceTime(500), distinctUntilChanged()).subscribe(s => {
            this.getListStream$.next({
                ...this.getListStream$.value,
                searchTerm: s
            });
        }));
        this.subscriptions.push(this.getListStream$.pipe(filter(Boolean), distinctUntilChanged((prev, curr) => JSON.stringify(prev) === JSON.stringify(curr)), tap(() => this.$loading.set(true)), switchMap(request => this.dbs.syncAndGetWorkflowSchemaMetadata(request).pipe(catchError(() => of({ ok: false, status: 500 })), finalize(() => this.$loading.set(false))))).subscribe((res) => {
            if (res.ok && res.status === 200 && res.body?.statusCode === 200) {
                this.wfs.$workflowDbSchema.set(res.body.innerBody.items);
                this.$totalItems.set(res.body.innerBody.totalItems);
            }
        }));
        setTimeout(() => {
            // Some more code...
        });
    }
    onTableShowMoreClicked(table, e) {
    }
    onListReorderUpdate(orderSet) {
        // Normalize ID to numbers
        const orderMap = new Map(orderSet.map(x => [Number(x.id), x.orderNum]));
        // Get current state
        const currentTables = this.wfs.$workflowDbSchema();
        // Rebuild reordered state
        const reordered = currentTables
            .map(table => ({
            ...table,
            orderNum: orderMap.get(table.id) ?? table.orderNum
        }))
            .sort((a, b) => (a.orderNum ?? 0) - (b.orderNum ?? 0));
        // Debug output
        console.log("🌀 Reordered Groups:", reordered);
        // Commit to signal/store
        this.wfs.$workflowDbSchema.set(reordered);
        // Optional: Trigger backend sync
        this.orderChanges$.next(reordered);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.5", ngImport: i0, type: DbSettingsComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.2.5", type: DbSettingsComponent, isStandalone: true, selector: "db-settings", usesInheritance: true, ngImport: i0, template: "<core-page-header\r\n  title=\"DB Settings For Workflow Builder\"\r\n  [hideButtonGroup]=\"true\"\r\n  [htmlTooltipRef]=\"htmlTooltipRef\"\r\n  >\r\n</core-page-header>\r\n\r\n<!-- <pre>{{ $activeHintEditorJson() }}</pre> -->\r\n\r\n<div class=\"container-fluid\">\r\n  <!-- \uD83D\uDD0D Search + Sort Toolbar -->\r\n  <div class=\"db-toolbar d-flex flex-wrap justify-content-between align-items-center mb-3 gap-3\">\r\n    <div class=\"search-box flex-grow-1\">\r\n      <input\r\n        type=\"text\"\r\n        class=\"form-control search-input\"\r\n        placeholder=\"Search tables or columns...\"\r\n        [(ngModel)]=\"searchTerm\"\r\n        (ngModelChange)=\"onSearchChange($event)\" />\r\n    </div>\r\n\r\n    <div>\r\n      <button class=\"btn btn-outline-secondary btn-sm sort-toggle-btn\" (click)=\"togglerSortMode()\">\r\n        {{ $sortMode() ? 'Expand' : 'Sort' }}\r\n      </button>\r\n    </div>\r\n  </div>\r\n\r\n  <!-- \uD83D\uDCE6 Workflow Schema Table List -->\r\n  <div class=\"group-list p-relative mt-4\">\r\n    @for (table of wfs.$workflowDbSchema(); track table.id) {\r\n\r\n      @defer(on viewport; on timer(5s)) {\r\n\r\n      @if ($sortMode()) {\r\n        <!-- Sort Mode: Draggable Card -->\r\n        <div\r\n          class=\"drag-item\"\r\n          [attr.data-id]=\"table.table\"\r\n          dragReorder\r\n          (updateList)=\"onListReorderUpdate($event)\">\r\n          <div class=\"col-md-12\">\r\n            <div class=\"table-wrapper\" [class.active]=\"!!table.isActive\">\r\n              <div class=\"item-header\">\r\n                <div class=\"table-name pointer\" [appTooltip]=\"table.hintForAi ?? ''\" [showAnyway]=\"true\">{{ table.table }}</div>\r\n              </div>\r\n            </div>\r\n          </div>\r\n        </div>\r\n      } @else {\r\n        <!-- Expanded Mode: Table with Columns -->\r\n        <div class=\"row gx-5 gy-4\">\r\n          <div class=\"col-md-12\">\r\n            <div class=\"table-wrapper\" [class.active]=\"!!table.isActive\">\r\n              <div class=\"item-header\">\r\n                <div class=\"table-name pointer\" [appTooltip]=\"table.hintForAi ?? ''\" [showAnyway]=\"true\" [class.has-hint]=\"!!table.hintForAi && !!table.hintForAi!.length\">{{ table.table }}</div>\r\n                <ai-hint-for-table [$table]=\"table\" />\r\n              </div>\r\n\r\n              <div class=\"item-columns\">\r\n                <core-sticker-collection\r\n                  [$items]=\"table.columns\"\r\n                  [$initialChecked]=\"getActiveColumnNameArray(table.table)\"\r\n                  [$shownFrom]=\"'column'\"\r\n                  [$tooltipFrom]=\"'hintForAi'\"\r\n                  [$showMore]=\"true\"\r\n                  [$showMoreTooltip]=\"'Set Hint for AI'\"\r\n                  [$hideShowMoreIfNotSelected]=\"true\"\r\n                  ($checkedChange)=\"onFieldToggle(table, $event)\"\r\n                  ($onShowMore)=\"openHintEditor(table, $event)\">\r\n                </core-sticker-collection>\r\n              </div>\r\n            </div>\r\n          </div>\r\n        </div>\r\n      }\r\n\r\n      } @placeholder() {\r\n        <p>{{ 'LOADING' | translate: lang }}</p>\r\n      }\r\n    }\r\n  </div>\r\n</div>\r\n\r\n<!-- \uD83C\uDF00 Fullscreen Loader -->\r\n@if ($loading()) {\r\n  <core-toast-loading />\r\n}\r\n\r\n@if (!!$activeHintEditor()) {\r\n    <ai-hint-for-column\r\n        [$table]=\"$activeHintEditor()?.table!\"\r\n        [$column]=\"$activeHintEditor()?.column!\"\r\n        [$top]=\"$activeHintEditor()?.top!\"\r\n        [$left]=\"$activeHintEditor()?.left!\"\r\n        ($closed)=\"closeHintEditor()\" />\r\n}\r\n\r\n<ng-template #htmlTooltipRef>\r\n\r\n  @if (lang==='en') {\r\n  <div class=\"db-settings-description\">\r\n  <h2>Database Schema Reference</h2>\r\n  <p>\r\n    This panel displays all available <strong>tables</strong> and their <strong>columns</strong> for use in your Workflow Builder.\r\n    Select relevant fields to build <em>dynamic conditions</em>, <em>actor resolvers</em>, or <em>calculated expressions</em>.\r\n  </p>\r\n  <p>\r\n    It's also used to power <strong>AI-assisted suggestions</strong>, giving intelligent autocompletion and validation based on your actual database structure.\r\n  </p>\r\n  <p class=\"note\">Tip: Hover over any column to see usage examples in your workflow.</p>\r\n  </div>\r\n  } @else {\r\n  <div class=\"db-settings-description\">\r\n  <h2>Tham chi\u1EBFu C\u1EA5u tr\u00FAc D\u1EEF li\u1EC7u</h2>\r\n  <p>\r\n    B\u1EA3ng d\u01B0\u1EDBi \u0111\u00E2y hi\u1EC3n th\u1ECB t\u1EA5t c\u1EA3 <strong>b\u1EA3ng d\u1EEF li\u1EC7u</strong> v\u00E0 c\u00E1c <strong>c\u1ED9t</strong> t\u01B0\u01A1ng \u1EE9ng trong h\u1EC7 th\u1ED1ng. \r\n    B\u1EA1n c\u00F3 th\u1EC3 ch\u1ECDn c\u00E1c c\u1ED9t n\u00E0y \u0111\u1EC3 x\u00E2y d\u1EF1ng <em>\u0111i\u1EC1u ki\u1EC7n \u0111\u1ED9ng</em>, <em>tr\u00ECnh ph\u00E2n gi\u1EA3i ng\u01B0\u1EDDi duy\u1EC7t</em>, ho\u1EB7c <em>bi\u1EC3u th\u1EE9c t\u00EDnh to\u00E1n</em>.\r\n  </p>\r\n  <p>\r\n    Giao di\u1EC7n n\u00E0y c\u0169ng h\u1ED7 tr\u1EE3 <strong>AI g\u1EE3i \u00FD th\u00F4ng minh</strong>, gi\u00FAp t\u1EF1 \u0111\u1ED9ng \u0111i\u1EC1n v\u00E0 ki\u1EC3m tra c\u00E1c bi\u1EC3u th\u1EE9c d\u1EF1a tr\u00EAn c\u1EA5u tr\u00FAc c\u01A1 s\u1EDF d\u1EEF li\u1EC7u th\u1EF1c t\u1EBF.\r\n  </p>\r\n  <p class=\"note\">M\u1EB9o: Di chu\u1ED9t v\u00E0o t\u00EAn c\u1ED9t \u0111\u1EC3 xem v\u00ED d\u1EE5 s\u1EED d\u1EE5ng trong lu\u1ED3ng ph\u00EA duy\u1EC7t.</p>\r\n  </div>\r\n\r\n  }\r\n\r\n</ng-template>", styles: ["@charset \"UTF-8\";.container-fluid{padding:24px;background-color:#f9f9fb;max-width:1000px}.db-toolbar{padding:16px;background-color:#fff;border-radius:8px}.search-input{width:100%;max-width:300px;padding:8px 12px;border-radius:6px;border:1px solid #ccc;transition:border-color .3s ease}.search-input:focus{border-color:#007bff;outline:none;background-color:#fff}.page-size-select{width:80px;min-width:80px;border-radius:6px;padding:4px 6px}.sort-toggle-btn{padding:6px 16px;border-radius:6px;font-weight:500;transition:all .2s ease-in-out}.sort-toggle-btn:hover{background-color:#e8e8e8;border-color:#bbb}.group-list{margin-top:20px}.drag-item{margin-bottom:16px;cursor:grab}.table-wrapper{background:#fff;border-radius:12px;padding:16px;box-shadow:0 2px 6px #0000000a;transition:box-shadow .2s ease,transform .2s ease;margin-bottom:15px}.table-wrapper.active{border-left:4px solid #4caf50}.item-header{display:flex;justify-content:space-between;align-items:center;margin-bottom:10px}.table-name{font-size:1.1rem;font-weight:600;color:#333}.table-name.has-hint{color:#2a9d8f;position:relative}.table-name.has-hint:after{content:\"\\1f4a1\";font-size:.9rem;margin-left:6px;vertical-align:middle;opacity:.8}.table-name.has-hint:hover:after{opacity:1}.item-columns{margin-top:10px;padding-top:10px;border-top:1px dashed #ddd}.db-settings-description{background-color:#f9fafb;padding:1rem 1.5rem;border-radius:.5rem;margin-bottom:1.5rem;color:#374151}.db-settings-description h2{margin:0 0 .5rem;font-size:1.25rem;font-weight:600;color:#1f2937}.db-settings-description p{margin:.25rem 0;line-height:1.5}.db-settings-description .note{margin-top:.75rem;font-size:.875rem;color:#6b7280}\n"], dependencies: [{ kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "component", type: CorePageHeaderComponent, selector: "core-page-header", inputs: ["instanceNumber", "shownItems", "title", "hideButtonGroup", "htmlTooltipRef"], outputs: ["buttonClick"] }, { kind: "component", type: CoreToastLoadingComponent, selector: "core-toast-loading" }, { kind: "pipe", type: TranslatePipe, name: "translate" }, { kind: "component", type: AiHintForColumnComponent, selector: "ai-hint-for-column", inputs: ["$table", "$column", "$top", "$left"], outputs: ["$closed"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, deferBlockDependencies: [() => [import('./ngx-histaff-alpha-core-sticker-collection.component-QQFZHJWt.mjs').then(m => m.CoreStickerCollectionComponent), import('./ngx-histaff-alpha-ngx-histaff-alpha-0x5r9IS0.mjs').then(function (n) { return n.eT; }).then(m => m.DragReorderDirective), import('./ngx-histaff-alpha-ngx-histaff-alpha-0x5r9IS0.mjs').then(function (n) { return n.eS; }).then(m => m.TooltipDirective), import('./ngx-histaff-alpha-ai-hint-for-table.component-CADAEfhL.mjs').then(m => m.AiHintForTableComponent)]] }); }
}
i0.ɵɵngDeclareClassMetadataAsync({ minVersion: "18.0.0", version: "19.2.5", ngImport: i0, type: DbSettingsComponent, resolveDeferredDeps: () => [import('./ngx-histaff-alpha-core-sticker-collection.component-QQFZHJWt.mjs').then(m => m.CoreStickerCollectionComponent), import('./ngx-histaff-alpha-ngx-histaff-alpha-0x5r9IS0.mjs').then(function (n) { return n.eT; }).then(m => m.DragReorderDirective), import('./ngx-histaff-alpha-ngx-histaff-alpha-0x5r9IS0.mjs').then(function (n) { return n.eS; }).then(m => m.TooltipDirective), import('./ngx-histaff-alpha-ai-hint-for-table.component-CADAEfhL.mjs').then(m => m.AiHintForTableComponent)], resolveMetadata: (CoreStickerCollectionComponent, DragReorderDirective, TooltipDirective, AiHintForTableComponent) => ({ decorators: [{
                type: Component,
                args: [{ selector: 'db-settings', changeDetection: ChangeDetectionStrategy.OnPush, imports: [
                            FormsModule,
                            CorePageHeaderComponent,
                            CoreStickerCollectionComponent,
                            CoreToastLoadingComponent,
                            DragReorderDirective,
                            TranslatePipe,
                            TooltipDirective,
                            AiHintForTableComponent,
                            AiHintForColumnComponent,
                        ], template: "<core-page-header\r\n  title=\"DB Settings For Workflow Builder\"\r\n  [hideButtonGroup]=\"true\"\r\n  [htmlTooltipRef]=\"htmlTooltipRef\"\r\n  >\r\n</core-page-header>\r\n\r\n<!-- <pre>{{ $activeHintEditorJson() }}</pre> -->\r\n\r\n<div class=\"container-fluid\">\r\n  <!-- \uD83D\uDD0D Search + Sort Toolbar -->\r\n  <div class=\"db-toolbar d-flex flex-wrap justify-content-between align-items-center mb-3 gap-3\">\r\n    <div class=\"search-box flex-grow-1\">\r\n      <input\r\n        type=\"text\"\r\n        class=\"form-control search-input\"\r\n        placeholder=\"Search tables or columns...\"\r\n        [(ngModel)]=\"searchTerm\"\r\n        (ngModelChange)=\"onSearchChange($event)\" />\r\n    </div>\r\n\r\n    <div>\r\n      <button class=\"btn btn-outline-secondary btn-sm sort-toggle-btn\" (click)=\"togglerSortMode()\">\r\n        {{ $sortMode() ? 'Expand' : 'Sort' }}\r\n      </button>\r\n    </div>\r\n  </div>\r\n\r\n  <!-- \uD83D\uDCE6 Workflow Schema Table List -->\r\n  <div class=\"group-list p-relative mt-4\">\r\n    @for (table of wfs.$workflowDbSchema(); track table.id) {\r\n\r\n      @defer(on viewport; on timer(5s)) {\r\n\r\n      @if ($sortMode()) {\r\n        <!-- Sort Mode: Draggable Card -->\r\n        <div\r\n          class=\"drag-item\"\r\n          [attr.data-id]=\"table.table\"\r\n          dragReorder\r\n          (updateList)=\"onListReorderUpdate($event)\">\r\n          <div class=\"col-md-12\">\r\n            <div class=\"table-wrapper\" [class.active]=\"!!table.isActive\">\r\n              <div class=\"item-header\">\r\n                <div class=\"table-name pointer\" [appTooltip]=\"table.hintForAi ?? ''\" [showAnyway]=\"true\">{{ table.table }}</div>\r\n              </div>\r\n            </div>\r\n          </div>\r\n        </div>\r\n      } @else {\r\n        <!-- Expanded Mode: Table with Columns -->\r\n        <div class=\"row gx-5 gy-4\">\r\n          <div class=\"col-md-12\">\r\n            <div class=\"table-wrapper\" [class.active]=\"!!table.isActive\">\r\n              <div class=\"item-header\">\r\n                <div class=\"table-name pointer\" [appTooltip]=\"table.hintForAi ?? ''\" [showAnyway]=\"true\" [class.has-hint]=\"!!table.hintForAi && !!table.hintForAi!.length\">{{ table.table }}</div>\r\n                <ai-hint-for-table [$table]=\"table\" />\r\n              </div>\r\n\r\n              <div class=\"item-columns\">\r\n                <core-sticker-collection\r\n                  [$items]=\"table.columns\"\r\n                  [$initialChecked]=\"getActiveColumnNameArray(table.table)\"\r\n                  [$shownFrom]=\"'column'\"\r\n                  [$tooltipFrom]=\"'hintForAi'\"\r\n                  [$showMore]=\"true\"\r\n                  [$showMoreTooltip]=\"'Set Hint for AI'\"\r\n                  [$hideShowMoreIfNotSelected]=\"true\"\r\n                  ($checkedChange)=\"onFieldToggle(table, $event)\"\r\n                  ($onShowMore)=\"openHintEditor(table, $event)\">\r\n                </core-sticker-collection>\r\n              </div>\r\n            </div>\r\n          </div>\r\n        </div>\r\n      }\r\n\r\n      } @placeholder() {\r\n        <p>{{ 'LOADING' | translate: lang }}</p>\r\n      }\r\n    }\r\n  </div>\r\n</div>\r\n\r\n<!-- \uD83C\uDF00 Fullscreen Loader -->\r\n@if ($loading()) {\r\n  <core-toast-loading />\r\n}\r\n\r\n@if (!!$activeHintEditor()) {\r\n    <ai-hint-for-column\r\n        [$table]=\"$activeHintEditor()?.table!\"\r\n        [$column]=\"$activeHintEditor()?.column!\"\r\n        [$top]=\"$activeHintEditor()?.top!\"\r\n        [$left]=\"$activeHintEditor()?.left!\"\r\n        ($closed)=\"closeHintEditor()\" />\r\n}\r\n\r\n<ng-template #htmlTooltipRef>\r\n\r\n  @if (lang==='en') {\r\n  <div class=\"db-settings-description\">\r\n  <h2>Database Schema Reference</h2>\r\n  <p>\r\n    This panel displays all available <strong>tables</strong> and their <strong>columns</strong> for use in your Workflow Builder.\r\n    Select relevant fields to build <em>dynamic conditions</em>, <em>actor resolvers</em>, or <em>calculated expressions</em>.\r\n  </p>\r\n  <p>\r\n    It's also used to power <strong>AI-assisted suggestions</strong>, giving intelligent autocompletion and validation based on your actual database structure.\r\n  </p>\r\n  <p class=\"note\">Tip: Hover over any column to see usage examples in your workflow.</p>\r\n  </div>\r\n  } @else {\r\n  <div class=\"db-settings-description\">\r\n  <h2>Tham chi\u1EBFu C\u1EA5u tr\u00FAc D\u1EEF li\u1EC7u</h2>\r\n  <p>\r\n    B\u1EA3ng d\u01B0\u1EDBi \u0111\u00E2y hi\u1EC3n th\u1ECB t\u1EA5t c\u1EA3 <strong>b\u1EA3ng d\u1EEF li\u1EC7u</strong> v\u00E0 c\u00E1c <strong>c\u1ED9t</strong> t\u01B0\u01A1ng \u1EE9ng trong h\u1EC7 th\u1ED1ng. \r\n    B\u1EA1n c\u00F3 th\u1EC3 ch\u1ECDn c\u00E1c c\u1ED9t n\u00E0y \u0111\u1EC3 x\u00E2y d\u1EF1ng <em>\u0111i\u1EC1u ki\u1EC7n \u0111\u1ED9ng</em>, <em>tr\u00ECnh ph\u00E2n gi\u1EA3i ng\u01B0\u1EDDi duy\u1EC7t</em>, ho\u1EB7c <em>bi\u1EC3u th\u1EE9c t\u00EDnh to\u00E1n</em>.\r\n  </p>\r\n  <p>\r\n    Giao di\u1EC7n n\u00E0y c\u0169ng h\u1ED7 tr\u1EE3 <strong>AI g\u1EE3i \u00FD th\u00F4ng minh</strong>, gi\u00FAp t\u1EF1 \u0111\u1ED9ng \u0111i\u1EC1n v\u00E0 ki\u1EC3m tra c\u00E1c bi\u1EC3u th\u1EE9c d\u1EF1a tr\u00EAn c\u1EA5u tr\u00FAc c\u01A1 s\u1EDF d\u1EEF li\u1EC7u th\u1EF1c t\u1EBF.\r\n  </p>\r\n  <p class=\"note\">M\u1EB9o: Di chu\u1ED9t v\u00E0o t\u00EAn c\u1ED9t \u0111\u1EC3 xem v\u00ED d\u1EE5 s\u1EED d\u1EE5ng trong lu\u1ED3ng ph\u00EA duy\u1EC7t.</p>\r\n  </div>\r\n\r\n  }\r\n\r\n</ng-template>", styles: ["@charset \"UTF-8\";.container-fluid{padding:24px;background-color:#f9f9fb;max-width:1000px}.db-toolbar{padding:16px;background-color:#fff;border-radius:8px}.search-input{width:100%;max-width:300px;padding:8px 12px;border-radius:6px;border:1px solid #ccc;transition:border-color .3s ease}.search-input:focus{border-color:#007bff;outline:none;background-color:#fff}.page-size-select{width:80px;min-width:80px;border-radius:6px;padding:4px 6px}.sort-toggle-btn{padding:6px 16px;border-radius:6px;font-weight:500;transition:all .2s ease-in-out}.sort-toggle-btn:hover{background-color:#e8e8e8;border-color:#bbb}.group-list{margin-top:20px}.drag-item{margin-bottom:16px;cursor:grab}.table-wrapper{background:#fff;border-radius:12px;padding:16px;box-shadow:0 2px 6px #0000000a;transition:box-shadow .2s ease,transform .2s ease;margin-bottom:15px}.table-wrapper.active{border-left:4px solid #4caf50}.item-header{display:flex;justify-content:space-between;align-items:center;margin-bottom:10px}.table-name{font-size:1.1rem;font-weight:600;color:#333}.table-name.has-hint{color:#2a9d8f;position:relative}.table-name.has-hint:after{content:\"\\1f4a1\";font-size:.9rem;margin-left:6px;vertical-align:middle;opacity:.8}.table-name.has-hint:hover:after{opacity:1}.item-columns{margin-top:10px;padding-top:10px;border-top:1px dashed #ddd}.db-settings-description{background-color:#f9fafb;padding:1rem 1.5rem;border-radius:.5rem;margin-bottom:1.5rem;color:#374151}.db-settings-description h2{margin:0 0 .5rem;font-size:1.25rem;font-weight:600;color:#1f2937}.db-settings-description p{margin:.25rem 0;line-height:1.5}.db-settings-description .note{margin-top:.75rem;font-size:.875rem;color:#6b7280}\n"] }]
            }], ctorParameters: null, propDecorators: null }) });

export { DbSettingsComponent };
//# sourceMappingURL=ngx-histaff-alpha-db-settings.component-Ds9XwP3W.mjs.map
