import { WritableSignal } from '@angular/core';
import { BehaviorSubject, Observable } from 'rxjs';
import { IAfInstance, IFormDesignCell, IFormDesignSection } from './interfaces';
import { ICoreFormSection, IFormBaseControl, IValidator } from '../core-form/core-form/enum-interfaces';
import { ICoreChecklistOption } from '../core-checklist/core-checklist/core-checklist.component';
import { FormGroup, ValidatorFn } from '@angular/forms';
import { EnumSupportedRuntimeValidator } from './enums/EnumSupportedRuntimeValidator';
import { AlertService } from '../alert/alert.service';
import { AppService } from '../../services/app.service';
import { EnumTranslateKey } from 'alpha-global-constants';
import { EnumCorePageEditMode } from '../core-page-edit/EnumCorePageEditMode';
import { IAfInstanceDTO } from './interfaces';
import { EnumFormDesignMode } from './enums/EnumFormDesignMode';
import { EnumCoreButtonVNSCode } from '../core-button-group-vns/core-button-group-vns/EnumCoreButtonVNSCode';
import { ICalculatedField } from '../core-workflow-builder/interfaces/ICalculatedField';
import * as i0 from "@angular/core";
export declare const URL_PATTERN: string;
export declare const READONLY_WORKFLOW_FIELDS: string[];
export declare class CoreFormDesignService {
    $afInstance: WritableSignal<IAfInstance>;
    $placeholderSections: WritableSignal<IFormDesignSection[]>;
    $sectionIndex: WritableSignal<number | null>;
    $rowIndex: WritableSignal<number | null>;
    $colIndex: WritableSignal<number | null>;
    $selectedCell: WritableSignal<IFormDesignCell | null>;
    $fieldSettingPanelOpen: WritableSignal<boolean>;
    $showFormMetadata: WritableSignal<boolean>;
    $currentControlTemplate: WritableSignal<Partial<IFormBaseControl> | null>;
    $currentControl: WritableSignal<IFormBaseControl | null>;
    $calculatedField: WritableSignal<ICalculatedField | null>;
    $submitText: WritableSignal<EnumTranslateKey>;
    editMode$: BehaviorSubject<EnumCorePageEditMode>;
    $customFormButtonItems: WritableSignal<EnumCoreButtonVNSCode[] | undefined>;
    $draggingControl: WritableSignal<Partial<IFormBaseControl> | null>;
    $shouldPatchMetadataForm: WritableSignal<boolean>;
    $currentControlJson: import("@angular/core").Signal<string>;
    $isInWorkflowDesign: WritableSignal<boolean>;
    $saveLiveJson: import("@angular/core").Signal<string>;
    $mode: WritableSignal<EnumFormDesignMode>;
    $liveFormNormalMode: WritableSignal<boolean>;
    $liveFormSections: WritableSignal<ICoreFormSection[]>;
    liveFormCrudMode$: BehaviorSubject<EnumCorePageEditMode>;
    formDesign: FormGroup;
    formMetadata: FormGroup;
    formMetadataCheckError$: BehaviorSubject<boolean>;
    alertService: AlertService;
    appService: AppService;
    formMetadataCustomButtonChecklistOptions$: BehaviorSubject<ICoreChecklistOption[]>;
    $formMetadataSections: WritableSignal<ICoreFormSection[]>;
    private stripRuntimeProps;
    constructor();
    $formContext: import("@angular/core").Signal<IFormBaseControl[]>;
    setControlProp<K extends keyof IFormBaseControl>(key: K, value: IFormBaseControl[K]): void;
    replaceControl(oldField: string | null, newControl: IFormBaseControl): void;
    setControlPropDirectly<K extends keyof IFormBaseControl>(key: K, value: IFormBaseControl[K], directControl?: IFormBaseControl): void;
    patchControl(updated: IFormBaseControl): void;
    beginDragTemplate(control: IFormBaseControl): void;
    endDrag(): void;
    isType(type: string): boolean;
    private readonly selfMappingTypes;
    private readonly defaultByControlType;
    normalize(control: Partial<IFormBaseControl>): IFormBaseControl;
    getDefaults(controlType: string): Partial<IFormBaseControl>;
    isRenderable(control: Partial<IFormBaseControl>): boolean;
    private generateUniqueField;
    private readonly propsComponentMap;
    getTypeSpecificPropsComponent(control: Partial<IFormBaseControl> | undefined): string;
    $currentPropsComponent: import("@angular/core").Signal<string>;
    generateFieldNameFor(control: Partial<IFormBaseControl>): string;
    generateLabelNameFor(control: Partial<IFormBaseControl>): string;
    getDetailedControlKey(control: Partial<IFormBaseControl>): string;
    getFriendlyControlLabel(control: Partial<IFormBaseControl>): string;
    camelToTitle(input: string): string;
    getAllControlsFromSections(): IFormBaseControl[];
    toIValidatorArray(config: Partial<Record<EnumSupportedRuntimeValidator, IValidator>>): IValidator[];
    buildValidator(name: EnumSupportedRuntimeValidator, input: Partial<IValidator>): IValidator | null;
    getSimpleValidator(name: 'required' | 'requiredTrue' | 'email'): ValidatorFn;
    getSupportedValidators(control: IFormBaseControl): EnumSupportedRuntimeValidator[];
    getControl(cell: IFormDesignCell): IFormBaseControl | null;
    getDefaultValidatorsFor(control: IFormBaseControl): IValidator[];
    getErrorMessageFor(v: EnumSupportedRuntimeValidator): string;
    getValidatorFn(v: EnumSupportedRuntimeValidator, value: any): ValidatorFn;
    buildValidatorFromName(name: EnumSupportedRuntimeValidator, value?: any, readOnly?: boolean): IValidator;
    buildValidatorFn(name: EnumSupportedRuntimeValidator, value?: any): ValidatorFn;
    createFormInstance(payload: IAfInstance): Observable<any>;
    updateFormInstance(payload: IAfInstance): Observable<any>;
    sanitizeSectionsForSaving(sections: IFormDesignSection[]): ICoreFormSection[];
    restoreValidator(v: any): any;
    toCoreFormSections(placeholderSections: IFormDesignSection[]): ICoreFormSection[];
    getById(id: string): Observable<any>;
    mapToAfInstanceDTO(form: IAfInstance): IAfInstanceDTO;
    safeStringify(obj: any): string;
    mapFromAfInstanceDTO(dto: IAfInstanceDTO): IAfInstance;
    syncPlaceholderSectionsFromInstance(): void;
    normalizeSections(sections: IFormDesignSection[]): IFormDesignSection[];
    sanitizeControl(control: Partial<IFormBaseControl>): IFormBaseControl;
    rehydrateSections(sections: IFormDesignSection[]): IFormDesignSection[];
    resetFormDesignState(): void;
    isValidatorFn(validator: any): validator is ValidatorFn;
    injectSystemControls(sections: ICoreFormSection[], hasIdOfStringType: boolean): ICoreFormSection[];
    rebuildSectionsFromControls(): IFormDesignSection[];
    updateCellAt(patch: Partial<IFormDesignCell>): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<CoreFormDesignService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<CoreFormDesignService>;
}
