import { FormGroup, ValidatorFn } from "@angular/forms";
import { EnumTranslateKey } from "alpha-global-constants";
import { EnumCoreFormControlSeekerSourceType } from "../../core-form-control-seeker/EnumCoreFormControlSeekerSourceType";
import { ICoreDropdownOption } from "../../../interfaces/ICoreDropdownOption";
import { BehaviorSubject } from "rxjs";
import { EnumCoreFileUploaderType } from "../../core-file-uploader/core-file-uploader/core-file-uploader.component";
import { EnumIconClass } from "../../../enum/EnumIconClass";
import { ICoreChecklistOption } from "../../core-checklist/core-checklist/core-checklist.component";
import { ICoreListOption } from "../../core-list/core-list/core-list.component";
import { EnumCoreTablePipeType } from "../../core-table/EnumCoreTablePipeType";
import { api } from "alpha-global-constants";
import { ICoreRadioOption } from "../../core-radio-group/core-radio-group/core-radio-group.component";
import { ICoreDatePickerRange } from "../../core-date-picker/core-date-picker/core-date-picker.component";
import { ICorePageListApiDefinition } from "../../core-page-list/core-page-list.component";
import { ICoreTableColumnItem } from "../../core-table/ICoreTableColumnItem";
import { EnumFormBaseContolType } from "../../../enum/EnumFormBaseContolType";
import { IFilterOperator } from "../../../interfaces/IQueryListRequest";
import { TemplateRef } from "@angular/core";
export interface IFormBaseDropdownOption {
    key: string;
    value: string;
}
export interface IValidator {
    name: string;
    validator: ValidatorFn;
    errorMessage: EnumTranslateKey | string;
    value?: any;
    readOnly?: boolean;
}
export interface ICoreFormControlSeekerExtraBindingModel {
    takeFrom: string;
    bindTo: string;
}
export interface ICoreFormSection {
    caption?: EnumTranslateKey | string;
    maxWidth?: number;
    iconClass?: EnumIconClass;
    addModeOnly?: boolean;
    updateModeOnly?: boolean;
    hidden?: boolean;
    forCalculatedFields?: boolean;
    rows: IFormBaseControl[][];
}
export interface ICoreFormSectionTab extends ICoreFormSection {
    tabTranslateCode: string;
}
export interface IFormBaseControl extends ICoreControlMandatory, ICoreControlOptional, ICoreControlCalculated, ICoreInputTypeNumber, ICoreTextarea, ICoreList, ICoreSeeker, ICoreMcc, ICoreDatePicker, ICoreGridBuffer, ICoreFileUploader, ICoreRadioGroup, ICoreDropdown, ICoreChecklist, ICoreAttachment {
}
interface ICoreControlMandatory {
    flexSize: number;
    controlType: EnumFormBaseContolType;
    field: string;
    label: EnumTranslateKey | string;
    value: any;
}
interface ICoreControlOptional {
    readonly?: boolean;
    hidden?: boolean;
    disabled?: boolean;
    type?: string;
    height?: number;
    popupHeight?: number;
    placeholder?: string;
    headless?: boolean;
    pipe?: EnumCoreTablePipeType;
    tooltip?: EnumTranslateKey | string;
    htmlTooltip?: TemplateRef<any>;
    hint?: EnumTranslateKey | string;
    validators?: IValidator[];
    focus$?: BehaviorSubject<any>;
    blur$?: BehaviorSubject<any>;
    click$?: BehaviorSubject<any>;
    selectedData$?: BehaviorSubject<any>;
    fullValueRow$?: BehaviorSubject<any>;
}
interface ICoreControlCalculated {
    script?: string;
    dependsOn?: string[];
    evaluationMode?: 'sql-query' | 'in-memory';
    returnType?: string;
    isUnsafe?: boolean;
}
interface ICoreBindingWYSINWYG {
    getByIdObject$?: BehaviorSubject<any>;
    getByIdApi?: api | string;
}
interface ICoreDynamicMapping {
    optionApiDriven?: boolean;
    optionApi?: string;
    optionHttpVerb?: 'HttpGet' | 'HttpPost';
    optionHttpPayload?: any;
    optionValueFrom?: string;
    optionTextFrom?: string;
}
interface ICoreDropdown extends ICoreBindingWYSINWYG, ICoreDynamicMapping {
    dropdownOptions$?: BehaviorSubject<ICoreDropdownOption[]>;
    options?: IFormBaseDropdownOption[];
    fitHeightWithItemCount?: boolean;
}
interface ICoreChecklist extends ICoreBindingWYSINWYG, ICoreDynamicMapping {
    checklistOptions$?: BehaviorSubject<ICoreChecklistOption[]>;
}
interface ICoreRadioGroup extends ICoreDynamicMapping {
    radioGroupOptions$?: BehaviorSubject<ICoreRadioOption[]>;
}
interface ICoreInputTypeNumber {
    step?: string;
}
interface ICoreTextarea {
    textareaRows?: number;
}
interface ICoreList extends ICoreBindingWYSINWYG {
    listOptions?: ICoreListOption[];
}
interface ICoreSeeker extends ICoreBindingWYSINWYG, ICoreSeekerMultiMode {
    multiMode?: boolean;
    seekerSourceType?: EnumCoreFormControlSeekerSourceType;
    useTheseColumns?: string[];
    excludedColumns?: string[];
    sourceSpaceHeight?: number;
    hideOrgTree?: boolean;
    boundFrom?: string;
    shownFrom?: string;
    alsoBindTo?: ICoreFormControlSeekerExtraBindingModel[];
    seekerVerifyIgnore?: boolean;
    preDefinedOuterParam$?: BehaviorSubject<any>;
    preDefinedOuterFilter$?: BehaviorSubject<IFilterOperator[]>;
}
interface ICoreSeekerMultiMode extends ICoreSeekerMultiModeEditable {
    objectList$?: BehaviorSubject<any[]>;
    getObjectListFrom?: string;
    excludeExistingList?: boolean;
    multiModeTableHeight?: number;
    multiModeRowHeight?: number;
}
interface ICoreSeekerMultiModeEditable extends ICoreSeekerMultiModeEditableIndirectBinding {
    multiModeExtendedColumns?: ICoreTableColumnItem[];
    multiModeExtendedSections?: ICoreFormSection[];
    editBufferData$?: BehaviorSubject<any>;
    indirectBinding?: boolean;
}
interface ICoreSeekerMultiModeEditableIndirectBinding {
    bindGridIdTo?: string;
}
interface ICoreMcc extends ICoreBindingWYSINWYG {
    columns?: ICoreTableColumnItem[];
    apiDefinition?: ICorePageListApiDefinition;
    selectedRow$?: BehaviorSubject<any>;
    outerParam$?: BehaviorSubject<any>;
    shownFrom?: string;
}
interface ICoreDatePicker {
    rangeLimit?: ICoreDatePickerRange;
    popupAlign?: string;
    showPlaceholder?: boolean;
}
interface ICoreGridBuffer {
    gridBufferFormSections?: ICoreFormSection[];
    gridBufferTableColumns?: ICoreTableColumnItem[];
    onBufferFormCreated?: (form: FormGroup) => void;
}
interface ICoreFileUploader {
    uploadFileType?: EnumCoreFileUploaderType;
    fileDataControlName?: string;
    fileNameControlName?: string;
    fileTypeControlName?: string;
    verticalMode?: boolean;
}
interface ICoreAttachment {
    assignTo?: string;
    valueToShow?: string;
}
export {};
