import { OnInit, AfterViewInit, OnDestroy, ElementRef, EventEmitter, OnChanges, SimpleChanges } from '@angular/core';
import { BehaviorSubject, Subject, Subscription } from 'rxjs';
import { RecursiveService } from '../../services/recursive.service';
import { CoreOrgTreeService } from '../core-org-tree.service';
import { AlertService } from '../../alert/alert.service';
import { IOrgTreeItem, IOrgTreeLinerItem } from './IOrgTreeItem';
import { ControlValueAccessor } from '@angular/forms';
import { CoreFormControlBaseComponent } from '../../core-form-control-base/core-form-control-base.component';
import { EnumTranslateKey } from "alpha-global-constants";
import { AuthService } from '../../../services/auth.service';
import { MultiLanguageService } from '../../../services/multi-language.service';
import { LayoutService } from '../../../services/layout.service';
import { OrganizationService } from '../../../services/organization.service';
import * as i0 from "@angular/core";
export declare enum EnumCoreOrgTreeaAccessorMode {
    ACTIVATED_SINGLE = "ACTIVATED_SINGLE",
    ACTIVATED_INHERITANCE = "ACTIVATED_INHERITANCE",
    CHECKED = "CHECKED"
}
export declare enum EnumCoreOrgTreeaSearchMode {
    HIGHLIGHT = "HIGHLIGHT",
    REDUCE = "REDUCE"
}
export declare class CoreOrgTreeComponent extends CoreFormControlBaseComponent implements OnChanges, OnInit, AfterViewInit, OnDestroy, ControlValueAccessor {
    private authService;
    private recursiveService;
    private mls;
    layoutService: LayoutService;
    private coreOrgTreeService;
    private alertService;
    organizationService: OrganizationService;
    lineColor: string;
    fullWidthMode: boolean;
    accessorMode: EnumCoreOrgTreeaAccessorMode | string;
    searchMode: EnumCoreOrgTreeaSearchMode;
    fullRendering: boolean;
    height: number;
    disabledLoopExpand: boolean;
    showCheckInheritance: boolean;
    excludedIds$: BehaviorSubject<number[]>;
    stateIsolated$: BehaviorSubject<boolean>;
    itemDoubleClick: EventEmitter<any>;
    itemClick: EventEmitter<any>;
    container: ElementRef;
    scrollContainer: ElementRef;
    displayContent: ElementRef;
    reducedIconWrapper: ElementRef;
    showSearch: boolean;
    hiddenToolClickStream$: BehaviorSubject<string>;
    value: number[];
    writeValue(obj: number[]): void;
    setDisabledState(disabled: boolean): void;
    activeIds: number[];
    checkedIds: number[];
    data: IOrgTreeItem[];
    loading: boolean;
    subscriptions: Subscription[];
    linnerOrgArray: IOrgTreeLinerItem[];
    search: string;
    search$: Subject<string>;
    reduced: boolean;
    searchPlaceholder: EnumTranslateKey;
    initializing: boolean;
    checkInheritance: boolean;
    showDissolved: boolean;
    selectedKey: string | undefined;
    selectedItem: IOrgTreeLinerItem;
    lang: string;
    instanceNumber: number;
    scrollContainerHeight: number;
    statusSubscription: Subscription;
    worker: Worker;
    constructor(authService: AuthService, recursiveService: RecursiveService, mls: MultiLanguageService, layoutService: LayoutService, coreOrgTreeService: CoreOrgTreeService, alertService: AlertService, organizationService: OrganizationService);
    ngOnChanges(changes: SimpleChanges): void;
    ngOnInit(): void;
    private resizeHeight;
    ngAfterViewInit(): void;
    onItemClickLocal(e: IOrgTreeItem): void;
    onToggleItem(e: IOrgTreeItem): void;
    buildTreeData(): void;
    onExpandTogglerClick(e: IOrgTreeItem, event: any): void;
    onItemCheck(e: IOrgTreeItem, newValue: boolean): void;
    onCheckIncludeDissolvedChange(value: boolean): void;
    onCheckInheritanceChange(value: boolean): void;
    onObjectClick(e: IOrgTreeItem, event: any): void;
    onSearchChange(text: string): void;
    onHiddenToolClick(e: any): void;
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<CoreOrgTreeComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<CoreOrgTreeComponent, "core-org-tree", never, { "lineColor": { "alias": "lineColor"; "required": false; }; "fullWidthMode": { "alias": "fullWidthMode"; "required": false; }; "accessorMode": { "alias": "accessorMode"; "required": false; }; "searchMode": { "alias": "searchMode"; "required": false; }; "fullRendering": { "alias": "fullRendering"; "required": false; }; "height": { "alias": "height"; "required": false; }; "disabledLoopExpand": { "alias": "disabledLoopExpand"; "required": false; }; "showCheckInheritance": { "alias": "showCheckInheritance"; "required": false; }; "excludedIds$": { "alias": "excludedIds$"; "required": false; }; "stateIsolated$": { "alias": "stateIsolated$"; "required": false; }; }, { "itemDoubleClick": "itemDoubleClick"; "itemClick": "itemClick"; }, never, never, true, never>;
}
