import { ElementRef, OnDestroy, OnInit, AfterViewInit, TemplateRef, EventEmitter, OnChanges, SimpleChanges } from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
import { ICoreTableToolClickEventEmitterData, ICoreTableToolItem } from '../core-table/core-table.component';
import { CorePageListService, IGenerateTemplateRequest } from './core-page-list.service';
import { CorePageEditService } from '../core-page-edit/core-page-edit.service';
import { AlertService } from '../alert/alert.service';
import { BehaviorSubject, Observable, Subscription } from 'rxjs';
import { CorePageListState } from './core-page-list.state';
import { ICoreButtonVNS } from '../core-button-group-vns/core-button-group-vns/ICoreButtonVNS';
import { EnumCoreButtonVNSCode } from '../core-button-group-vns/core-button-group-vns/EnumCoreButtonVNSCode';
import { CoreFormControlBaseComponent } from '../core-form-control-base/core-form-control-base.component';
import { ICoreCommonParamKitEventEmitterData } from '../core-common-param-kit/core-common-param-kit/core-common-param-kit.component';
import { LongTaskService } from '../services/long-task.service';
import { CoreCompositionService } from '../core-composition/core-composition.service';
import { CoreButtonGroupService } from '../core-button-group-vns/core-button-group-service';
import { ICoreButtonGroupStatus } from '../core-button-group-vns/core-button-group-service';
import { IFilterOperator, IInOperator, IPagination, IQueryListRequest, ISearchItem, ISortItem } from '../../interfaces/IQueryListRequest';
import { api } from "alpha-global-constants";
import { EnumTranslateKey } from "alpha-global-constants";
import { MultiLanguageService } from '../../services/multi-language.service';
import { AuthService } from '../../services/auth.service';
import { AppService } from '../../services/app.service';
import { DialogService } from '../../services/dialog.service';
import { RoutingService } from '../../services/routing.service';
import { LayoutService } from '../../services/layout.service';
import { JsonService } from '../../services/json.service';
import { ICoreTableColumnItem } from '../core-table/ICoreTableColumnItem';
import { ICoreChecklistOption } from '../core-checklist/core-checklist/core-checklist.component';
import { WorkShiftDndService } from '../../services/work-shift-dnd.service';
import { DomService } from '../services/dom.service';
import { FilterKitService } from '../../services/filter-kit.service';
import { ICoreParamControl } from '../core-header-params/enum-and-interfaces';
import { CoreFilterHubService } from '../core-filter-hub/core-filter-hub.service';
import { CoreTableService } from '../../services/core-table.service';
import * as i0 from "@angular/core";
export interface ICorePageListApiDefinition {
    queryListRelativePath: string;
}
export interface ICorePageListSearchObject {
    previous: ISearchItem[];
    current: ISearchItem[];
}
export interface ICorePageListEditRouting {
    auxiliary: string;
}
export interface ICorePageListCRUD {
    deleteIds?: api | string;
    toggleActiveIds?: api | string;
    toggleApproveIds?: api | string;
    toggleUnapproveIds?: api | string;
}
export interface IXlsxImportObject {
    xlsxSid: string;
    xlsxExCode: string;
    xlsxSession: number;
}
export interface ICorePageListStatusTab {
    id: number | null;
    intlCode?: string;
    text: string;
    count: number;
}
export interface ICoreTableFlatColumnItem {
    caption: string;
    field: string;
    type?: string;
    pipe?: string;
    align?: string;
    width?: number;
    hidden?: boolean;
}
export declare class CorePageListComponent extends CoreFormControlBaseComponent implements OnInit, AfterViewInit, OnChanges, OnDestroy {
    private corePageListService;
    private corePageListState;
    private corePageEditService;
    private router;
    private route;
    private mls;
    private alertService;
    private authService;
    private appService;
    private dialogService;
    private routingService;
    private longTaskService;
    layoutService: LayoutService;
    private coreCompositionService;
    private coreButtonGroupService;
    private jsonService;
    private workShiftDndService;
    private domService;
    private filterKitService;
    private coreFilterHubService;
    private coreTableService;
    normalMode: boolean;
    hideHeader: boolean;
    hideButtonGroup: boolean;
    seekerMode: boolean;
    mccMode: boolean;
    height: number;
    headerWrap: boolean;
    headerFirstRowHeight: number;
    /** */
    /**Show ParamKit */
    enableTimeZoneConverterForDateTimePeriodParameters: boolean;
    showParamKit: boolean;
    enableFilterKit: boolean;
    datePeriodComparisonFor: string;
    datePeriodComparisonForLabelKey: EnumTranslateKey;
    statusInclusionFor: string;
    statusInclusionForLabelKey: EnumTranslateKey;
    statusOptionsApi: api | string;
    statusOptions$: BehaviorSubject<ICoreChecklistOption[]>;
    showOrgParam: boolean;
    showOrgParamDropdown: boolean;
    hideGeneralSearch: boolean;
    hideDatePeriodComparison: boolean;
    hideStatusInclusion: boolean;
    filterOperators$: BehaviorSubject<IFilterOperator[]>;
    camelCaseDtoStatusIdField: string;
    gridStatusColumn: string;
    /**End Show ParamKit */
    title: EnumTranslateKey | string;
    hasIdOfStringType: boolean;
    hideCheck: boolean;
    apiDefinition: ICorePageListApiDefinition;
    columns: ICoreTableColumnItem[];
    useTheseColumns: string[];
    hideOrgTree: boolean;
    frozen: number;
    inlineTools: ICoreTableToolItem[];
    inlineToolItems: EnumCoreButtonVNSCode[];
    editRoute: ICorePageListEditRouting;
    crud: ICorePageListCRUD;
    showListInlineTools: boolean;
    top: TemplateRef<any>;
    left: TemplateRef<any> | undefined;
    hideLeft: boolean;
    outerParam$: BehaviorSubject<any>;
    outerFilter$: BehaviorSubject<IFilterOperator[] | undefined>;
    outerSort: ISortItem[];
    outerFilterOperators: IFilterOperator[];
    outerInOperators: IInOperator[] | null;
    autoResizeWithWindow: boolean;
    extraManualOffset: number;
    wrap: boolean;
    rowHeight: string;
    selfResolveCorePageHeaderButtonClick: boolean;
    clearData$: BehaviorSubject<boolean>;
    deleteValidateFn: Function;
    generateTemplateRequest: IGenerateTemplateRequest;
    importPreviewPath: string;
    columnSearchDefaultOpen: boolean;
    fixedPageSize: number;
    disableDoubleClick: boolean;
    noPaddingCell: boolean;
    disableHighlightOnClick: boolean;
    loading$: BehaviorSubject<boolean>;
    excludedIds$: BehaviorSubject<number[]>;
    disableDialogInformationLines: boolean;
    changeTracking: boolean;
    primaryKey: string;
    changedItems$: BehaviorSubject<any[]>;
    tabMode: boolean;
    paramRows: ICoreParamControl[][];
    disableFilterHub: boolean;
    autoColumnFitAvailableSpace: boolean;
    ignoredDefaultActions: string[];
    checkboxExplicity: boolean;
    corePageHeaderButtonClick: EventEmitter<ICoreButtonVNS>;
    rowClick: EventEmitter<any>;
    rowDoubleClick: EventEmitter<any>;
    selectedIdsChange: EventEmitter<any>;
    selectedDataChange: EventEmitter<any>;
    onInstanceCreated: EventEmitter<number>;
    onInputFileBase64DataReady: EventEmitter<any>;
    listChange: EventEmitter<any[]>;
    container: ElementRef;
    corePageListContainer: ElementRef;
    paginationContainer: ElementRef;
    fileImport: ElementRef;
    geometricDone: boolean;
    heightResizing: boolean;
    height$: BehaviorSubject<number>;
    topPlaceHeight$: BehaviorSubject<number>;
    resizeHeightFlag$: BehaviorSubject<boolean>;
    paginationHeight: number;
    compositionHeight: number;
    corePageListInstanceNumber: number;
    dialogInstanceNumber: number;
    resizeStream$: Observable<Event>;
    clickGenerateTemplate$: BehaviorSubject<number>;
    subscriptions: Subscription[];
    queryListSubscription: Subscription;
    loading: boolean;
    selectedIds: string[] | number[];
    selectedData: any[];
    isAdmin: boolean;
    viewInitDone: boolean;
    pageCount: number;
    currentPage$: BehaviorSubject<number>;
    pageSize$: BehaviorSubject<number>;
    filter$: BehaviorSubject<any>;
    inOperators$: BehaviorSubject<IInOperator[]>;
    generalSearch$: BehaviorSubject<string>;
    search$: BehaviorSubject<ICorePageListSearchObject | null>;
    sort$: BehaviorSubject<ISortItem[]>;
    pagination$: BehaviorSubject<IPagination>;
    forceReloadingFlag$: BehaviorSubject<boolean>;
    queryListRequest$: BehaviorSubject<IQueryListRequest>;
    queryListStream$: Observable<any>;
    innerBodyCount$: BehaviorSubject<number>;
    pauseSubsctiption: boolean;
    list: any[];
    tableHeight: number;
    availableColumnsForGeneralSearch: string[];
    dataImport: any;
    pendingAction: EnumCoreButtonVNSCode | null;
    idState: any;
    templateFileName: string;
    longApiRunning: boolean;
    prefetchLoading: boolean;
    buttonGroupStatus: ICoreButtonGroupStatus;
    exportCorePageListGridToExcelSubscription: Subscription;
    statusTabs: Map<number, ICorePageListStatusTab>;
    tabHeaders: string[];
    filterKitZIndex: number;
    showFilter: boolean;
    confirmationColumns: ICoreTableColumnItem[];
    constructor(corePageListService: CorePageListService, corePageListState: CorePageListState, corePageEditService: CorePageEditService, router: Router, route: ActivatedRoute, mls: MultiLanguageService, alertService: AlertService, authService: AuthService, appService: AppService, dialogService: DialogService, routingService: RoutingService, longTaskService: LongTaskService, layoutService: LayoutService, coreCompositionService: CoreCompositionService, coreButtonGroupService: CoreButtonGroupService, jsonService: JsonService, workShiftDndService: WorkShiftDndService, domService: DomService, filterKitService: FilterKitService, coreFilterHubService: CoreFilterHubService, coreTableService: CoreTableService);
    ngOnChanges(changes: SimpleChanges): void;
    subscribeQueryList(x: any): void;
    mergeFilterOperator(): void;
    tmpFilterActive: boolean;
    tmpInOperatorsActive: boolean;
    primaryFilter: any;
    primaryInOperators: IInOperator[];
    outerParamSubscribeFn(): void;
    resolveUseTheseColumns(value: string[]): void;
    ngOnInit(): void;
    onRowDoubleClick(event: any): void;
    onRowClick(e: any): void;
    onToolClick(event: ICoreTableToolClickEventEmitterData): void;
    onSearching(e: ISearchItem[]): void;
    private resizeHeightWhenContainerHasFixedHeight;
    private resizeHeightWhenContainerHasUndefinedHeight;
    private resizeHeight$;
    private resizeHeight;
    queryListSubscribe(): void;
    calculateTableHeightBasedOnHeightAndTopRefHeight(height: number, topRefHeight: number): void;
    ngAfterViewInit(): void;
    onParamKitValueChange(data: ICoreCommonParamKitEventEmitterData): void;
    exportToExcel(): void;
    onCorePageHeaderButtonClick(e: ICoreButtonVNS): void;
    onSelectedIdsChange(e: string[] | number[]): void;
    onSelectedDataChange(e: any[]): void;
    onColumnCaptionClick(e: ICoreTableColumnItem): void;
    inputFile: (e: any) => Promise<void>;
    browseFileInput(): void;
    onProgressWindowClose(_: any): void;
    onCoreTabsHeaderClick(e: any): void;
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<CorePageListComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<CorePageListComponent, "core-page-list", never, { "normalMode": { "alias": "normalMode"; "required": false; }; "hideHeader": { "alias": "hideHeader"; "required": false; }; "hideButtonGroup": { "alias": "hideButtonGroup"; "required": false; }; "seekerMode": { "alias": "seekerMode"; "required": false; }; "mccMode": { "alias": "mccMode"; "required": false; }; "height": { "alias": "height"; "required": false; }; "headerWrap": { "alias": "headerWrap"; "required": false; }; "headerFirstRowHeight": { "alias": "headerFirstRowHeight"; "required": false; }; "enableTimeZoneConverterForDateTimePeriodParameters": { "alias": "enableTimeZoneConverterForDateTimePeriodParameters"; "required": false; }; "showParamKit": { "alias": "showParamKit"; "required": false; }; "enableFilterKit": { "alias": "enableFilterKit"; "required": false; }; "datePeriodComparisonFor": { "alias": "datePeriodComparisonFor"; "required": false; }; "datePeriodComparisonForLabelKey": { "alias": "datePeriodComparisonForLabelKey"; "required": false; }; "statusInclusionFor": { "alias": "statusInclusionFor"; "required": false; }; "statusInclusionForLabelKey": { "alias": "statusInclusionForLabelKey"; "required": false; }; "statusOptionsApi": { "alias": "statusOptionsApi"; "required": false; }; "statusOptions$": { "alias": "statusOptions$"; "required": false; }; "showOrgParam": { "alias": "showOrgParam"; "required": false; }; "showOrgParamDropdown": { "alias": "showOrgParamDropdown"; "required": false; }; "hideGeneralSearch": { "alias": "hideGeneralSearch"; "required": false; }; "hideDatePeriodComparison": { "alias": "hideDatePeriodComparison"; "required": false; }; "hideStatusInclusion": { "alias": "hideStatusInclusion"; "required": false; }; "filterOperators$": { "alias": "filterOperators$"; "required": false; }; "camelCaseDtoStatusIdField": { "alias": "camelCaseDtoStatusIdField"; "required": false; }; "gridStatusColumn": { "alias": "gridStatusColumn"; "required": false; }; "title": { "alias": "title"; "required": false; }; "hasIdOfStringType": { "alias": "hasIdOfStringType"; "required": false; }; "hideCheck": { "alias": "hideCheck"; "required": false; }; "apiDefinition": { "alias": "apiDefinition"; "required": true; }; "columns": { "alias": "columns"; "required": true; }; "useTheseColumns": { "alias": "useTheseColumns"; "required": false; }; "hideOrgTree": { "alias": "hideOrgTree"; "required": false; }; "frozen": { "alias": "frozen"; "required": false; }; "inlineTools": { "alias": "inlineTools"; "required": false; }; "inlineToolItems": { "alias": "inlineToolItems"; "required": false; }; "editRoute": { "alias": "editRoute"; "required": false; }; "crud": { "alias": "crud"; "required": false; }; "showListInlineTools": { "alias": "showListInlineTools"; "required": false; }; "top": { "alias": "top"; "required": false; }; "left": { "alias": "left"; "required": false; }; "hideLeft": { "alias": "hideLeft"; "required": false; }; "outerParam$": { "alias": "outerParam$"; "required": false; }; "outerFilter$": { "alias": "outerFilter$"; "required": false; }; "outerSort": { "alias": "outerSort"; "required": false; }; "outerFilterOperators": { "alias": "outerFilterOperators"; "required": false; }; "outerInOperators": { "alias": "outerInOperators"; "required": false; }; "autoResizeWithWindow": { "alias": "autoResizeWithWindow"; "required": false; }; "extraManualOffset": { "alias": "extraManualOffset"; "required": false; }; "wrap": { "alias": "wrap"; "required": false; }; "rowHeight": { "alias": "rowHeight"; "required": false; }; "selfResolveCorePageHeaderButtonClick": { "alias": "selfResolveCorePageHeaderButtonClick"; "required": false; }; "clearData$": { "alias": "clearData$"; "required": false; }; "deleteValidateFn": { "alias": "deleteValidateFn"; "required": false; }; "generateTemplateRequest": { "alias": "generateTemplateRequest"; "required": false; }; "importPreviewPath": { "alias": "importPreviewPath"; "required": false; }; "columnSearchDefaultOpen": { "alias": "columnSearchDefaultOpen"; "required": false; }; "fixedPageSize": { "alias": "fixedPageSize"; "required": false; }; "disableDoubleClick": { "alias": "disableDoubleClick"; "required": false; }; "noPaddingCell": { "alias": "noPaddingCell"; "required": false; }; "disableHighlightOnClick": { "alias": "disableHighlightOnClick"; "required": false; }; "loading$": { "alias": "loading$"; "required": false; }; "excludedIds$": { "alias": "excludedIds$"; "required": false; }; "disableDialogInformationLines": { "alias": "disableDialogInformationLines"; "required": false; }; "changeTracking": { "alias": "changeTracking"; "required": false; }; "primaryKey": { "alias": "primaryKey"; "required": false; }; "changedItems$": { "alias": "changedItems$"; "required": false; }; "tabMode": { "alias": "tabMode"; "required": false; }; "paramRows": { "alias": "paramRows"; "required": false; }; "disableFilterHub": { "alias": "disableFilterHub"; "required": false; }; "autoColumnFitAvailableSpace": { "alias": "autoColumnFitAvailableSpace"; "required": false; }; "ignoredDefaultActions": { "alias": "ignoredDefaultActions"; "required": false; }; "checkboxExplicity": { "alias": "checkboxExplicity"; "required": false; }; }, { "corePageHeaderButtonClick": "corePageHeaderButtonClick"; "rowClick": "rowClick"; "rowDoubleClick": "rowDoubleClick"; "selectedIdsChange": "selectedIdsChange"; "selectedDataChange": "selectedDataChange"; "onInstanceCreated": "onInstanceCreated"; "onInputFileBase64DataReady": "onInputFileBase64DataReady"; "listChange": "listChange"; }, never, never, true, never>;
}
