import { ElementRef, OnInit, OnDestroy, AfterViewInit, OnChanges, SimpleChanges, EventEmitter, QueryList, Renderer2, ChangeDetectorRef } from '@angular/core';
import { Subscription, BehaviorSubject, Observable } from 'rxjs';
import { CorePageListService } from '../core-page-list/core-page-list.service';
import { CoreFormControlBaseComponent } from '../core-form-control-base/core-form-control-base.component';
import { ICoreButtonVNS } from '../core-button-group-vns/core-button-group-vns/ICoreButtonVNS';
import { EnumCoreButtonVNSCode } from '../core-button-group-vns/core-button-group-vns/EnumCoreButtonVNSCode';
import { EnumTranslateKey } from "alpha-global-constants";
import { ISearchItem } from '../../interfaces/IQueryListRequest';
import { LayoutService } from '../../services/layout.service';
import { MultiLanguageService } from '../../services/multi-language.service';
import { AlertService } from '../alert/alert.service';
import { AuthService } from '../../services/auth.service';
import { ICoreTableColumnItem } from './ICoreTableColumnItem';
import { DndService } from '../../services/dnd.service';
import * as i0 from "@angular/core";
export declare enum ECoreTableToolCode {
    edit = "edit",
    delete = "delete",
    complete = "complete",
    navigate = "navigate"
}
export declare enum ECoreTableToolClass {
    edit = "edit-icon",
    delete = "delete-icon",
    repeat = "repeat-icon",
    navigate = "navigate-icon"
}
export interface ICoreTableToolItem {
    code: ECoreTableToolCode;
    class: ECoreTableToolClass;
    caption?: EnumTranslateKey | string;
    disabledFn?: (row: any) => boolean;
    hiddenFn?: (row: any) => boolean;
}
export interface ICoreTableToolClickEventEmitterData {
    code: ECoreTableToolCode;
    id: string | number;
}
interface IDoubleTouchendData {
    previous: number;
    current: number;
}
export declare class CoreTableComponent extends CoreFormControlBaseComponent implements OnInit, AfterViewInit, OnChanges, OnDestroy {
    private layoutService;
    private corePageListService;
    private mls;
    private alertService;
    private authService;
    private renderer;
    private dndService;
    private elRef;
    private cdr;
    resizers: QueryList<ElementRef<any>>;
    columnCaptions: QueryList<ElementRef<any>>;
    tbody: ElementRef<any>;
    id: string;
    width: string;
    height: number;
    showCheckbox: boolean;
    checkboxSize: number;
    outerButtons: ICoreButtonVNS[];
    showTools: boolean;
    tools: ICoreTableToolItem[];
    checkingResetFlag: boolean;
    borderRadius: number;
    headerColor: string;
    headerBackgroundColor: string;
    headerWrap: boolean;
    headerFirstRowHeight: number;
    /** */
    headerSecondRowHeight: number;
    wrap: boolean;
    allowCellScrollY: boolean;
    loading: boolean;
    rowHeight: string;
    frozen: number;
    footer: any;
    columns: ICoreTableColumnItem[];
    data: any[];
    selectedIds: string[] | number[];
    corePageListInstanceNumber: number;
    disableHighlightOnClick: boolean;
    freeMode: boolean;
    searchSwitchDisabled: boolean;
    disableSorting: boolean;
    inlineToolItems: EnumCoreButtonVNSCode[];
    columnSearchDefaultOpen: boolean;
    lazyLoading: boolean;
    primaryKey: string;
    rowHoverBgColor: string;
    noPaddingCell: boolean;
    autoColumnFitAvailableSpace: boolean;
    checkboxExplicity: boolean;
    onSearching: EventEmitter<ISearchItem[]>;
    onToolClick: EventEmitter<ICoreTableToolClickEventEmitterData>;
    onRowClick: EventEmitter<any>;
    onRowDoubleClick: EventEmitter<any>;
    onSelectedIdsChange: EventEmitter<string[] | number[]>;
    onSelectedDataChange: EventEmitter<any[]>;
    onColumnCaptionClick: EventEmitter<ICoreTableColumnItem>;
    private verticalLine;
    checkboxColumnWidth: number;
    searchActive: boolean;
    visibleColumns: ICoreTableColumnItem[];
    visibleWidth: number;
    isTableWiderThanContainer: boolean;
    frozenLefts: number[];
    checkingModel: boolean[];
    headerCheckboxState: boolean;
    checkingState: number;
    tbodyheight: number;
    visibleRowCount: number;
    rowTouchendStream$: BehaviorSubject<IDoubleTouchendData>;
    subscriptions: Subscription[];
    searchObject: ISearchItem[];
    lang: string;
    activeRow: any;
    visibleColumnIndex: number;
    startX: any;
    endX: any;
    private dragSubscriptions;
    private dragendSubscriptions;
    private dragstartSubscriptions;
    private dragenterSubscriptions;
    private dragoverSubscriptions;
    scrollStream$: Observable<any>;
    renderAhread: number;
    hiddenTopHeight: number;
    hiddenBottomHeight: number;
    scrollTop: number;
    offsetY: number;
    visibleData: any[];
    startNode: number;
    /***********************/
    loadingHeight: number;
    coreTable: ElementRef;
    table: ElementRef;
    firstHeaderRow: ElementRef;
    hasAggregateCols: boolean;
    constructor(layoutService: LayoutService, corePageListService: CorePageListService, mls: MultiLanguageService, alertService: AlertService, authService: AuthService, renderer: Renderer2, dndService: DndService, elRef: ElementRef, cdr: ChangeDetectorRef);
    hasAggregateColumns(): boolean;
    computeAggregate(option: string | undefined, field: string): number | string;
    calculateScroll(): void;
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    private resetHeaderFirstRowHeight;
    private showVerticalLine;
    private hideVerticalLine;
    private updateVerticalLinePosition;
    private adjustColumnWidths;
    ngAfterViewInit(): void;
    private addDragAndDragEndListeners;
    private cleanupDragAndDragEndSubscriptions;
    registerReizersEvents(): void;
    onToolClickLocal(row: any, toolIndex: number): void;
    toggleCheckAll(args: boolean): void;
    onCheckingNgModelChange(): void;
    onDoubleClickLocal(rowIndex: number): void;
    onClickLocal(row: any, event: any, index: number): void;
    onRowTouchend(rowIndex: number): void;
    onSearch(e: string, searchColumnIndex: number): void;
    onColumnCaptionClickLocal(column: ICoreTableColumnItem): void;
    toggleAllowSearch(): void;
    onInlineToolClick(e: ICoreButtonVNS, row: any): void;
    ngOnDestroy(): void;
    /**
      function that checks if the event.target is within the
      tr, tr > td, or tr > td > div structure,
      and returns true or false accordingly.
     */
    canHandleRowClickForCheckbox(event: MouseEvent): boolean;
    private isInValidZone;
    static ɵfac: i0.ɵɵFactoryDeclaration<CoreTableComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<CoreTableComponent, "core-table", never, { "id": { "alias": "id"; "required": false; }; "width": { "alias": "width"; "required": false; }; "height": { "alias": "height"; "required": false; }; "showCheckbox": { "alias": "showCheckbox"; "required": false; }; "checkboxSize": { "alias": "checkboxSize"; "required": false; }; "outerButtons": { "alias": "outerButtons"; "required": false; }; "showTools": { "alias": "showTools"; "required": false; }; "tools": { "alias": "tools"; "required": false; }; "checkingResetFlag": { "alias": "checkingResetFlag"; "required": false; }; "borderRadius": { "alias": "borderRadius"; "required": false; }; "headerColor": { "alias": "headerColor"; "required": false; }; "headerBackgroundColor": { "alias": "headerBackgroundColor"; "required": false; }; "headerWrap": { "alias": "headerWrap"; "required": false; }; "headerFirstRowHeight": { "alias": "headerFirstRowHeight"; "required": false; }; "headerSecondRowHeight": { "alias": "headerSecondRowHeight"; "required": false; }; "wrap": { "alias": "wrap"; "required": false; }; "allowCellScrollY": { "alias": "allowCellScrollY"; "required": false; }; "loading": { "alias": "loading"; "required": false; }; "rowHeight": { "alias": "rowHeight"; "required": false; }; "frozen": { "alias": "frozen"; "required": false; }; "footer": { "alias": "footer"; "required": false; }; "columns": { "alias": "columns"; "required": true; }; "data": { "alias": "data"; "required": true; }; "selectedIds": { "alias": "selectedIds"; "required": false; }; "corePageListInstanceNumber": { "alias": "corePageListInstanceNumber"; "required": false; }; "disableHighlightOnClick": { "alias": "disableHighlightOnClick"; "required": false; }; "freeMode": { "alias": "freeMode"; "required": false; }; "searchSwitchDisabled": { "alias": "searchSwitchDisabled"; "required": false; }; "disableSorting": { "alias": "disableSorting"; "required": false; }; "inlineToolItems": { "alias": "inlineToolItems"; "required": false; }; "columnSearchDefaultOpen": { "alias": "columnSearchDefaultOpen"; "required": false; }; "lazyLoading": { "alias": "lazyLoading"; "required": false; }; "primaryKey": { "alias": "primaryKey"; "required": false; }; "rowHoverBgColor": { "alias": "rowHoverBgColor"; "required": false; }; "noPaddingCell": { "alias": "noPaddingCell"; "required": false; }; "autoColumnFitAvailableSpace": { "alias": "autoColumnFitAvailableSpace"; "required": false; }; "checkboxExplicity": { "alias": "checkboxExplicity"; "required": false; }; }, { "onSearching": "onSearching"; "onToolClick": "onToolClick"; "onRowClick": "onRowClick"; "onRowDoubleClick": "onRowDoubleClick"; "onSelectedIdsChange": "onSelectedIdsChange"; "onSelectedDataChange": "onSelectedDataChange"; "onColumnCaptionClick": "onColumnCaptionClick"; }, never, never, true, never>;
}
export {};
