import { WritableSignal } from '@angular/core';
import { BehaviorSubject, Observable, Subscription } from 'rxjs';
import { AppService } from '../../services/app.service';
import { IWfWorkflowGroup } from './interfaces/IWfWorkflowGroup';
import { IWfWorkflow } from './interfaces/IWfWorkflow';
import { IStep } from './interfaces/IStep';
import { EnumWorkflowStepType } from './enums/EnumWorkflowStepType';
import { IWorkflowBranch } from './interfaces/IWorkflowBranch';
import { IWorkflowInsertPoint } from './interfaces/IWorkflowInsertPoint';
import { IFormBaseControl } from '../core-form/core-form/enum-interfaces';
import { IActorAssignment } from './interfaces/IActorAssignment';
import { IStepConfig } from './interfaces/IStepConfig';
import { AlertService } from '../alert/alert.service';
import { Router } from '@angular/router';
import { CoreFormDesignService } from '../core-form-design/core-form-design.service';
import { JsonService } from '../../services/json.service';
import { IRoutingStep } from './interfaces/IRoutingStep';
import { FormGroup } from '@angular/forms';
import { IWorkflowSchemaTable } from './interfaces/IWorkflowSchema';
import { IGenerateWorkflowRoutingRequest } from './interfaces/IGenerateWorkflowRoutingRequest';
import { CoreParamControlService } from '../core-param-control/core-param-control.service';
import { IIdsRequest } from '../../interfaces/IIdsRequest';
import { IInitialDebugSubmitRequest } from './interfaces/IInitialDebugSubmitRequest';
import { AppConfigService } from '../../services/app-config.service';
import * as i0 from "@angular/core";
export declare class CoreWorkflowService {
    private appService;
    private alertService;
    private fds;
    js: JsonService;
    acs: AppConfigService;
    coreParamControlService: CoreParamControlService;
    private readonly invalidStepKeys;
    $workflowDbSchema: WritableSignal<IWorkflowSchemaTable[]>;
    $loading: WritableSignal<boolean>;
    $allGroups: WritableSignal<IWfWorkflowGroup[]>;
    $currentGroup: WritableSignal<IWfWorkflowGroup | null>;
    $currentFlow: WritableSignal<IWfWorkflow | null>;
    $currentStep: WritableSignal<IStep | null>;
    $availableCols: import("@angular/core").Signal<IFormBaseControl[]>;
    $showStepConfig: WritableSignal<boolean>;
    $stepUpdated: WritableSignal<number>;
    standardConnectorHeight: number;
    /**
      id: string;
      name: string;
      branchId: string;
      type: EnumWorkflowStepType;
      label: string;
      config?: IStepConfig;
      branches?: IWorkflowBranch[];
      isPseudo?: boolean;
      isInFallbackBranch?: boolean;
    */
    $currentSteps: WritableSignal<IStep[]>;
    $showCurrentStepsPreview: WritableSignal<boolean>;
    $selectedActorAssignment: WritableSignal<IActorAssignment | undefined>;
    $initialBasicInfoJson: WritableSignal<string>;
    $initialFormDesignJson: WritableSignal<string>;
    $initialProcessDesignJson: WritableSignal<string>;
    $initialMoreJson: WritableSignal<string>;
    $currentBasicInfoJson: WritableSignal<string>;
    $currentFormDesignJson: import("@angular/core").Signal<string>;
    $currentProcessDesignJson: import("@angular/core").Signal<string>;
    $basicInfoChanged: import("@angular/core").Signal<boolean>;
    $formDesignChanged: import("@angular/core").Signal<boolean>;
    $processDesignChanged: import("@angular/core").Signal<boolean>;
    $moreChanged: import("@angular/core").Signal<boolean>;
    $designActiveTab: WritableSignal<number>;
    $simulatedEmployee: WritableSignal<any>;
    $showLiveRouting: WritableSignal<boolean>;
    insertContext$: BehaviorSubject<IWorkflowInsertPoint | null>;
    insertAnchorPoint$: BehaviorSubject<DOMRect | null>;
    subscriptions: Subscription[];
    router: Router;
    jsonService: JsonService;
    $routingSteps: WritableSignal<IRoutingStep[]>;
    basicInfoForm: FormGroup;
    basicInfoFormCheckError$: BehaviorSubject<boolean>;
    liveForm: FormGroup;
    liveFormCheckError$: BehaviorSubject<boolean>;
    $stepsJsonPreview: import("@angular/core").Signal<string>;
    constructor(appService: AppService, alertService: AlertService, fds: CoreFormDesignService);
    newWorkflow(): IWfWorkflow;
    updateStep(updatedStep: IStep): void;
    refresh(endpoint: string | undefined, searchTerm: string, currentGroupId?: number | undefined, published?: boolean): void;
    createConditionalBranchStep(branchId: string): IStep;
    createStep(type: EnumWorkflowStepType, branchId: string, label: string): {
        id: `${string}-${string}-${string}-${string}-${string}`;
        name: string;
        branchId: string;
        type: EnumWorkflowStepType;
        label: string;
    };
    getNextIndexByStepType(type: EnumWorkflowStepType): number;
    autoReassignPriorities(branches: IWorkflowBranch[]): void;
    findStepRecursive(steps: IStep[], targetId: string): IStep | null;
    addBranchToStep(stepId: string): void;
    loadWorkflowWithAfInstance(workflowId: string): Observable<any>;
    loadAfInstance(afInstanceId: string): Observable<any>;
    extractValidFieldsFromSections(sectionsJson: string): IFormBaseControl[];
    updateGroupOrder(newOrder: IWfWorkflowGroup[]): Observable<any>;
    toggleFlowLock(flowId: string): Observable<any>;
    updateTableOrder(newOrder: IWorkflowSchemaTable[]): Observable<any>;
    updateStepsSignalAfterNestedChange(signal: WritableSignal<IStep[]>, mutate: (draft: IStep[]) => void): void;
    saveCurrentSteps(): void;
    publish(): Observable<any>;
    getById(id: string): void;
    deepStepFind(sources: IStep[], id: string): IStep | undefined;
    updateCurrentStepConfig(configPatch: Partial<IStepConfig>): void;
    loadByIdWithAfInstance(workflowId: string): void;
    loadProcessDesign(): void;
    generateRouting(request: IGenerateWorkflowRoutingRequest): Observable<any>;
    getEmployeesByIds(payload: IIdsRequest): Observable<any>;
    getPositionsByIds(payload: IIdsRequest): Observable<any>;
    initialDebugSubmit(request: IInitialDebugSubmitRequest): Observable<any>;
    react(unitedCorrelationIds: string, reactType: string, reason: string): Observable<any>;
    static ɵfac: i0.ɵɵFactoryDeclaration<CoreWorkflowService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<CoreWorkflowService>;
}
