import { ElementRef, TemplateRef, OnDestroy, AfterViewInit, Renderer2 } from '@angular/core';
import { BehaviorSubject, Subscription } from 'rxjs';
import { Router } from '@angular/router';
import { DomSanitizer, SafeHtml } from '@angular/platform-browser';
import { NavigatorService } from '../../../services/navigator.service';
import { SysMenuService } from '../../../services/sys-menu.service';
import { RecursiveService } from '../../services/recursive.service';
import { IRightIcon } from '../../../interfaces/IRightIcon';
import { INavigatorItem } from '../../../interfaces/INavigatorItem';
import { MenuService } from '../../../services/menu.service';
import { OrganizationService } from '../../../services/organization.service';
import { AuthService } from '../../../services/auth.service';
import { LayoutService } from '../../../services/layout.service';
import { MultiLanguageService } from '../../../services/multi-language.service';
import { AlertService } from '../../alert/alert.service';
import { AppConfigService } from '../../../services/app-config.service';
import * as i0 from "@angular/core";
interface IFlatNavigationCheck {
    id: number;
    count: number;
}
export declare class NavigatorComponent implements AfterViewInit, OnDestroy {
    navigatorService: NavigatorService;
    private sysMenuService;
    private recursiveService;
    private router;
    menuService: MenuService;
    private organizationService;
    layoutService: LayoutService;
    private mls;
    private authService;
    private alertService;
    private appConfigService;
    private sanitizer;
    private renderer;
    height: number;
    filterByRootIdMode: boolean;
    color: string | undefined;
    backgroundColor: string | undefined;
    activeItemColor: string | undefined;
    activeItemBackgroundColor: string | undefined;
    hoverBackgroundColor: string | undefined;
    hideSearch: boolean | undefined;
    subMenuSvgIconRight: string;
    secondaryNavHeaderColor: string;
    secondaryNavHeaderBackgroundColor: string;
    secondaryNavColor: string;
    secondaryNavBackgroundColor: string;
    secondaryNavHoverColor: string;
    secondaryNavHoverBackgroundColor: string;
    container: ElementRef;
    mainMenu: ElementRef;
    listenerFn: () => void;
    lang: string;
    items: INavigatorItem[];
    isFirstLoad: boolean;
    showEditSvg: boolean;
    logoTemplate: TemplateRef<any>;
    rightPartHeadeMenuItem: INavigatorItem;
    rightIcon: IRightIcon;
    linerItems$: BehaviorSubject<INavigatorItem[]>;
    linerItems: INavigatorItem[];
    subscriptions: Subscription[];
    flatNavigationCheck: IFlatNavigationCheck[];
    itemsErrors: string[];
    leftbarReduced: boolean;
    leftbarCurrentWidth: number;
    secondaryNavTop: number;
    secondaryNavHeight: number;
    secondaryNavWidth: number;
    secondaryNavParent: any;
    secondaryNavChildren: any[];
    loading: boolean;
    placeholder: string;
    searchFor: string;
    searchStream$: BehaviorSubject<string>;
    menuClickedItem: INavigatorItem;
    checkedLoadingMenu: boolean;
    wideMode: boolean;
    scrollHeight: number;
    resizeStream$: import("rxjs").Observable<Event>;
    leftBarWideWidth: number;
    safeIconSvg(): SafeHtml | null;
    geoCompute(): void;
    constructor(navigatorService: NavigatorService, sysMenuService: SysMenuService, recursiveService: RecursiveService, router: Router, menuService: MenuService, organizationService: OrganizationService, layoutService: LayoutService, mls: MultiLanguageService, authService: AuthService, alertService: AlertService, appConfigService: AppConfigService, sanitizer: DomSanitizer, renderer: Renderer2);
    ngOnInit(): void;
    resolveRawDataResponseForRootList(x: any): void;
    resolveRawDataResponse(x: any): void;
    ngAfterViewInit(): void;
    onSearchChange(e: string): void;
    clearSearch(): void;
    validateNavigationItem(item: INavigatorItem): void;
    hasChildren(item: INavigatorItem): boolean;
    itemHasChildren(item: INavigatorItem): boolean;
    onItemClick(item: INavigatorItem): void;
    ngOnDestroy(): void;
    toggleCollapse(): void;
    onSecondaryItemClick(item: any): void;
    onSecondaryHeaderClick(parent: any): void;
    onCancelSecondaryMenu(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<NavigatorComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<NavigatorComponent, "corelib-navigator", never, { "height": { "alias": "height"; "required": false; }; "filterByRootIdMode": { "alias": "filterByRootIdMode"; "required": false; }; "color": { "alias": "color"; "required": false; }; "backgroundColor": { "alias": "backgroundColor"; "required": false; }; "activeItemColor": { "alias": "activeItemColor"; "required": false; }; "activeItemBackgroundColor": { "alias": "activeItemBackgroundColor"; "required": false; }; "hoverBackgroundColor": { "alias": "hoverBackgroundColor"; "required": false; }; "hideSearch": { "alias": "hideSearch"; "required": false; }; "subMenuSvgIconRight": { "alias": "subMenuSvgIconRight"; "required": false; }; "secondaryNavHeaderColor": { "alias": "secondaryNavHeaderColor"; "required": false; }; "secondaryNavHeaderBackgroundColor": { "alias": "secondaryNavHeaderBackgroundColor"; "required": false; }; "secondaryNavColor": { "alias": "secondaryNavColor"; "required": false; }; "secondaryNavBackgroundColor": { "alias": "secondaryNavBackgroundColor"; "required": false; }; "secondaryNavHoverColor": { "alias": "secondaryNavHoverColor"; "required": false; }; "secondaryNavHoverBackgroundColor": { "alias": "secondaryNavHoverBackgroundColor"; "required": false; }; "logoTemplate": { "alias": "logoTemplate"; "required": false; }; "rightPartHeadeMenuItem": { "alias": "rightPartHeadeMenuItem"; "required": false; }; "rightIcon": { "alias": "rightIcon"; "required": false; }; }, {}, never, never, true, never>;
}
export {};
